@@ -104,10 +104,10 @@ void agilent_82350b_remote_enable( gpib_board_t *board, int enable )
 	agilent_82350b_private_t *priv = board->private_data;
 	tms9914_remote_enable( board, &priv->tms9914_priv, enable );
 }
-void agilent_82350b_enable_eos( gpib_board_t *board, uint8_t eos_byte, int compare_8_bits )
+int agilent_82350b_enable_eos( gpib_board_t *board, uint8_t eos_byte, int compare_8_bits )
 {
 	agilent_82350b_private_t *priv = board->private_data;
-	tms9914_enable_eos( board, &priv->tms9914_priv, eos_byte, compare_8_bits );
+	return tms9914_enable_eos( board, &priv->tms9914_priv, eos_byte, compare_8_bits );
 }
 void agilent_82350b_disable_eos( gpib_board_t *board )
 {
@@ -275,16 +275,16 @@ int agilent_82350b_generic_attach(gpib_board_t *board, int use_fifos)
 	}
 	if(pci_request_regions(a_priv->pci_device, "agilent_82350b"))
 		return -EIO;
-	a_priv->gpib_base = (unsigned long) ioremap(pci_resource_start(a_priv->pci_device, GPIB_REGION),
+	a_priv->gpib_base = ioremap(pci_resource_start(a_priv->pci_device, GPIB_REGION),
 		pci_resource_len(a_priv->pci_device, GPIB_REGION));
-	printk("%s: gpib base address remapped to 0x%lx\n", __FUNCTION__, a_priv->gpib_base );
+	printk("%s: gpib base address remapped to 0x%p\n", __FUNCTION__, a_priv->gpib_base );
 	tms_priv->iobase = a_priv->gpib_base + TMS9914_BASE_REG;
-	a_priv->sram_base = (unsigned long) ioremap(pci_resource_start(a_priv->pci_device, SRAM_REGION),
+	a_priv->sram_base = ioremap(pci_resource_start(a_priv->pci_device, SRAM_REGION),
 		pci_resource_len(a_priv->pci_device, SRAM_REGION));
-	printk("%s: sram base address remapped to 0x%lx\n", __FUNCTION__, a_priv->sram_base );
-	a_priv->misc_base = (unsigned long) ioremap(pci_resource_start(a_priv->pci_device, MISC_REGION),
+	printk("%s: sram base address remapped to 0x%p\n", __FUNCTION__, a_priv->sram_base );
+	a_priv->misc_base = ioremap(pci_resource_start(a_priv->pci_device, MISC_REGION),
 		pci_resource_len(a_priv->pci_device, MISC_REGION));
-	printk("%s: misc base address remapped to 0x%lx\n", __FUNCTION__, a_priv->misc_base );
+	printk("%s: misc base address remapped to 0x%p\n", __FUNCTION__, a_priv->misc_base );
 
 	if(request_irq(a_priv->pci_device->irq, agilent_82350b_interrupt, SA_SHIRQ, "agilent_82350b", board))
 	{
@@ -361,7 +361,7 @@ void agilent_82350b_detach(gpib_board_t *board)
 	agilent_82350b_free_private( board );
 }
 
-static struct pci_device_id agilent_82350b_pci_table[] __devinitdata = 
+static const struct pci_device_id agilent_82350b_pci_table[] = 
 {
 	{ PCI_VENDOR_ID_AGILENT, PCI_DEVICE_ID_82350B, PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0 },
 	{ 0 }
