@@ -1,5 +1,5 @@
 /***************************************************************************
-                          agilent_82357a/agilent_82357a.c  
+                          agilent_82357a/agilent_82357a.c
                              -------------------
  driver for Agilent 82357A usb to gpib adapters
 
@@ -31,9 +31,9 @@ static DECLARE_MUTEX(agilent_82357a_hotplug_lock);
 static void agilent_82357a_bulk_complete(struct urb *urb, struct pt_regs *regs)
 {
 	agilent_82357a_urb_context_t *context = urb->context;
-	
+
 //	printk("debug: %s: %s: status=0x%x, error_count=%i, actual_length=%i\n", __FILE__, __FUNCTION__,
-//		urb->status, urb->error_count, urb->actual_length); 
+//		urb->status, urb->error_count, urb->actual_length);
 
 	up(&context->complete);
 }
@@ -45,195 +45,217 @@ static void agilent_82357a_timeout_handler(unsigned long arg)
 	up(&context->complete);
 }
 
-int agilent_82357a_send_bulk_msg(agilent_82357a_private_t *a_priv, void *data, int data_length, int *actual_data_length, 
+int agilent_82357a_send_bulk_msg(agilent_82357a_private_t *a_priv, void *data, int data_length, int *actual_data_length,
 	int timeout_msecs)
 {
 	struct usb_device *usb_dev;
 	int retval;
 	unsigned int out_pipe;
 	agilent_82357a_urb_context_t context;
-	struct timer_list timer;
-		
+	struct timer_list *timer = NULL;
+
 	*actual_data_length = 0;
-	retval = down_interruptible(&a_priv->bulk_transfer_lock);
+	retval = down_interruptible(&a_priv->bulk_alloc_lock);
 	if(retval) return retval;
 	if(a_priv->bus_interface == NULL)
 	{
-		up(&a_priv->bulk_transfer_lock);
+		up(&a_priv->bulk_alloc_lock);
 		return -ENODEV;
 	}
-	if(a_priv->bulk_urb) 
+	if(a_priv->bulk_urb)
 	{
-		up(&a_priv->bulk_transfer_lock);
+		up(&a_priv->bulk_alloc_lock);
 		return -EAGAIN;
 	}
 	a_priv->bulk_urb = usb_alloc_urb(0, GFP_KERNEL);
 	if(a_priv->bulk_urb == NULL)
 	{
-		up(&a_priv->bulk_transfer_lock);
+		up(&a_priv->bulk_alloc_lock);
 		return -ENOMEM;
 	}
 	usb_dev = interface_to_usbdev(a_priv->bus_interface);
 	out_pipe = usb_sndbulkpipe(usb_dev, AGILENT_82357A_BULK_OUT_ENDPOINT);
 	init_MUTEX_LOCKED(&context.complete);
 	context.timed_out = 0;
-	usb_fill_bulk_urb(a_priv->bulk_urb, usb_dev, out_pipe, data, data_length, 
+	usb_fill_bulk_urb(a_priv->bulk_urb, usb_dev, out_pipe, data, data_length,
 		agilent_82357a_bulk_complete, &context);
-	init_timer(&timer);
-	timer.expires = jiffies + msecs_to_jiffies(timeout_msecs);
-	timer.function = agilent_82357a_timeout_handler;
-	timer.data = (unsigned long) &context;
-	add_timer(&timer);
+	timer = kmalloc(sizeof(struct timer_list), GFP_KERNEL);
+	if(timer == NULL)
+	{
+		up(&a_priv->bulk_alloc_lock);
+		retval = -ENOMEM;
+		goto cleanup;
+	}
+	init_timer(timer);
+	timer->expires = jiffies + msecs_to_jiffies(timeout_msecs);
+	timer->function = agilent_82357a_timeout_handler;
+	timer->data = (unsigned long) &context;
+	add_timer(timer);
 	//printk("%s: submitting urb\n", __FUNCTION__);
 	retval = usb_submit_urb(a_priv->bulk_urb, GFP_KERNEL);
-	if(retval) 
+	if(retval)
 	{
-		usb_free_urb(a_priv->bulk_urb);
-		a_priv->bulk_urb = NULL;
 		printk("%s: failed to submit bulk out urb, retval=%i\n", __FILE__, retval);
-		up(&a_priv->bulk_transfer_lock);
-		return retval;
+		up(&a_priv->bulk_alloc_lock);
+		goto cleanup;
 	}
-	up(&a_priv->bulk_transfer_lock);
+	up(&a_priv->bulk_alloc_lock);
 	if(down_interruptible(&context.complete))
 	{
 		printk("%s: %s: interrupted\n", __FILE__, __FUNCTION__);
-		usb_kill_urb(a_priv->bulk_urb);
-		down(&a_priv->bulk_transfer_lock);
-		usb_free_urb(a_priv->bulk_urb);
-		a_priv->bulk_urb = NULL;
-		up(&a_priv->bulk_transfer_lock);	
-		return -ERESTARTSYS;
+		retval = -ERESTARTSYS;
+		goto cleanup;
 	}
-	if(context.timed_out) 
+	if(context.timed_out)
 	{
-		usb_kill_urb(a_priv->bulk_urb);
 		retval = -ETIMEDOUT;
 	}else
+	{
 		retval = a_priv->bulk_urb->status;
-	if(timer_pending(&timer))
-		del_timer_sync(&timer);
-	*actual_data_length = a_priv->bulk_urb->actual_length;
-	down(&a_priv->bulk_transfer_lock);
-	usb_free_urb(a_priv->bulk_urb);
-	a_priv->bulk_urb = NULL;
-	up(&a_priv->bulk_transfer_lock);	
+		*actual_data_length = a_priv->bulk_urb->actual_length;
+	}
+cleanup:
+	if(timer)
+	{		
+		if(timer_pending(timer))
+			del_timer_sync(timer);
+		kfree(timer);
+	}
+	down(&a_priv->bulk_alloc_lock);
+	if(a_priv->bulk_urb)
+	{
+		usb_kill_urb(a_priv->bulk_urb);
+		usb_free_urb(a_priv->bulk_urb);
+		a_priv->bulk_urb = NULL;
+	}
+	up(&a_priv->bulk_alloc_lock);
 	return retval;
 }
 
-int agilent_82357a_receive_bulk_msg(agilent_82357a_private_t *a_priv, void *data, int data_length, int *actual_data_length, 
+int agilent_82357a_receive_bulk_msg(agilent_82357a_private_t *a_priv, void *data, int data_length, int *actual_data_length,
 	int timeout_msecs)
 {
 	struct usb_device *usb_dev;
 	int retval;
 	unsigned int in_pipe;
 	agilent_82357a_urb_context_t context;
-	struct timer_list timer;
-	
+	struct timer_list *timer = NULL;
+
 	*actual_data_length = 0;
-	retval = down_interruptible(&a_priv->bulk_transfer_lock);
+	retval = down_interruptible(&a_priv->bulk_alloc_lock);
 	if(retval) return retval;
 	if(a_priv->bus_interface == NULL)
 	{
-		up(&a_priv->bulk_transfer_lock);
+		up(&a_priv->bulk_alloc_lock);
 		return -ENODEV;
 	}
-	if(a_priv->bulk_urb) 
+	if(a_priv->bulk_urb)
 	{
-		up(&a_priv->bulk_transfer_lock);
+		up(&a_priv->bulk_alloc_lock);
 		return -EAGAIN;
 	}
 	a_priv->bulk_urb = usb_alloc_urb(0, GFP_KERNEL);
 	if(a_priv->bulk_urb == NULL)
 	{
-		up(&a_priv->bulk_transfer_lock);
+		up(&a_priv->bulk_alloc_lock);
 		return -ENOMEM;
 	}
 	usb_dev = interface_to_usbdev(a_priv->bus_interface);
 	in_pipe = usb_rcvbulkpipe(usb_dev, AGILENT_82357A_BULK_IN_ENDPOINT);
 	init_MUTEX_LOCKED(&context.complete);
 	context.timed_out = 0;
-	usb_fill_bulk_urb(a_priv->bulk_urb, usb_dev, in_pipe, data, data_length, 
+	usb_fill_bulk_urb(a_priv->bulk_urb, usb_dev, in_pipe, data, data_length,
 		agilent_82357a_bulk_complete, &context);
-	init_timer(&timer);
-	timer.expires = jiffies + msecs_to_jiffies(timeout_msecs);
-	timer.function = agilent_82357a_timeout_handler;
-	timer.data = (unsigned long) &context;
-	add_timer(&timer);
+	timer = kmalloc(sizeof(struct timer_list), GFP_KERNEL);
+	if(timer == NULL)
+	{
+		retval = -ENOMEM;
+		up(&a_priv->bulk_alloc_lock);
+		goto cleanup;
+	}
+	init_timer(timer);
+	timer->expires = jiffies + msecs_to_jiffies(timeout_msecs);
+	timer->function = agilent_82357a_timeout_handler;
+	timer->data = (unsigned long) &context;
+	add_timer(timer);
 	//printk("%s: submitting urb\n", __FUNCTION__);
 	retval = usb_submit_urb(a_priv->bulk_urb, GFP_KERNEL);
-	if(retval) 
+	if(retval)
 	{
-		usb_free_urb(a_priv->bulk_urb);
-		a_priv->bulk_urb = NULL;
 		printk("%s: failed to submit bulk out urb, retval=%i\n", __FILE__, retval);
-		up(&a_priv->bulk_transfer_lock);
-		return retval;
+		up(&a_priv->bulk_alloc_lock);
+		goto cleanup;
 	}
-	up(&a_priv->bulk_transfer_lock);
+	up(&a_priv->bulk_alloc_lock);
 	if(down_interruptible(&context.complete))
 	{
 		printk("%s: %s: interrupted\n", __FILE__, __FUNCTION__);
-		usb_kill_urb(a_priv->bulk_urb);
-		down(&a_priv->bulk_transfer_lock);
-		usb_free_urb(a_priv->bulk_urb);
-		a_priv->bulk_urb = NULL;
-		up(&a_priv->bulk_transfer_lock);	
-		return -ERESTARTSYS;
+		retval = -ERESTARTSYS;
+		goto cleanup;
 	}
-	if(context.timed_out) 
+	if(context.timed_out)
+	{
+		retval = -ETIMEDOUT;
+		goto cleanup;
+	}
+	retval = a_priv->bulk_urb->status;
+	*actual_data_length = a_priv->bulk_urb->actual_length;
+cleanup:
+	if(timer)
+	{
+		if(timer_pending(timer))
+		{
+			del_timer_sync(timer);
+		}
+		kfree(timer);
+	}
+	down(&a_priv->bulk_alloc_lock);
+	if(a_priv->bulk_urb)
 	{
 		usb_kill_urb(a_priv->bulk_urb);
-		retval = -ETIMEDOUT;
-	}else
-		retval = a_priv->bulk_urb->status;
-	if(timer_pending(&timer))
-		del_timer_sync(&timer);
-	*actual_data_length = a_priv->bulk_urb->actual_length;
-	retval = a_priv->bulk_urb->status;
-	down(&a_priv->bulk_transfer_lock);
-	usb_free_urb(a_priv->bulk_urb);
-	a_priv->bulk_urb = NULL;
-	up(&a_priv->bulk_transfer_lock);	
+		usb_free_urb(a_priv->bulk_urb);
+		a_priv->bulk_urb = NULL;
+	}
+	up(&a_priv->bulk_alloc_lock);
 	return retval;
 }
 
-int agilent_82357a_receive_control_msg(agilent_82357a_private_t *a_priv, __u8 request, __u8 requesttype, __u16 value, 
+int agilent_82357a_receive_control_msg(agilent_82357a_private_t *a_priv, __u8 request, __u8 requesttype, __u16 value,
 	__u16 index, void *data, __u16 size, int timeout_msecs)
 {
 	struct usb_device *usb_dev;
 	int retval;
 	unsigned int in_pipe;
-	
-	retval = down_interruptible(&a_priv->control_transfer_lock);
+
+	retval = down_interruptible(&a_priv->control_alloc_lock);
 	if(retval) return retval;
 	if(a_priv->bus_interface == NULL)
 	{
-		up(&a_priv->control_transfer_lock);
+		up(&a_priv->control_alloc_lock);
 		return -ENODEV;
 	}
 	usb_dev = interface_to_usbdev(a_priv->bus_interface);
 	in_pipe = usb_rcvctrlpipe(usb_dev, AGILENT_82357A_CONTROL_ENDPOINT);
 	retval = USB_CONTROL_MSG(usb_dev, in_pipe, request, requesttype, value, index, data, size, timeout_msecs);
-	up(&a_priv->control_transfer_lock);
+	up(&a_priv->control_alloc_lock);
 	return retval;
 }
 
 static void agilent_82357a_dump_raw_block(const uint8_t *raw_data, int length)
 {
 	int i;
-	
+
 	printk("%s:", __FUNCTION__);
 	for(i = 0; i < length; ++i)
 	{
 		if(i % 8 == 0)
-			printk("\n"); 
+			printk("\n");
 		printk(" %2x", raw_data[i]);
 	}
 	printk("\n");
 }
 
-int agilent_82357a_write_registers(agilent_82357a_private_t *a_priv, const struct agilent_82357a_register_pairlet *writes, 
+int agilent_82357a_write_registers(agilent_82357a_private_t *a_priv, const struct agilent_82357a_register_pairlet *writes,
 	int num_writes)
 {
 	int retval;
@@ -245,7 +267,7 @@ int agilent_82357a_write_registers(agilent_82357a_private_t *a_priv, const struc
 	static const int bytes_per_write = 2;
 	static const int header_length = 2;
 	static const int max_writes = 31;
-	
+
 	if(num_writes > max_writes)
 	{
 		printk("%s: %s: bug! num_writes=%i too large\n", __FILE__, __FUNCTION__, num_writes);
@@ -254,27 +276,34 @@ int agilent_82357a_write_registers(agilent_82357a_private_t *a_priv, const struc
 	out_data_length = num_writes * bytes_per_write + header_length;
 	out_data = kmalloc(out_data_length, GFP_KERNEL);
 	if(out_data == NULL)
-	{	
+	{
 		printk("%s: %s: kmalloc failed\n", __FILE__, __FUNCTION__);
 		return -ENOMEM;
 	}
 	out_data[i++] = DATA_PIPE_CMD_WR_REGS;
 	out_data[i++] = num_writes;
 	for(j = 0; j < num_writes; j++)
-	{	
+	{
 		out_data[i++] = writes[j].address;
 		out_data[i++] = writes[j].value;
-	}	
+	}
 	if(i > out_data_length)
 	{
 		printk("%s: bug! buffer overrun\n", __FUNCTION__);
 	}
+	retval = down_interruptible(&a_priv->bulk_transfer_lock);
+	if(retval)
+	{
+		kfree(out_data);
+		return retval;
+	}
 	retval = agilent_82357a_send_bulk_msg(a_priv, out_data, i, &bytes_written, 1000);
 	kfree(out_data);
 	if(retval)
 	{
-		printk("%s: %s: agilent_82357a_send_bulk_msg returned %i, bytes_written=%i, i=%i\n", __FILE__, __FUNCTION__, 
-			retval, bytes_written, i);		
+		printk("%s: %s: agilent_82357a_send_bulk_msg returned %i, bytes_written=%i, i=%i\n", __FILE__, __FUNCTION__,
+			retval, bytes_written, i);
+		up(&a_priv->bulk_transfer_lock);
 		return retval;
 	}
 	in_data_length = 0x20;
@@ -282,9 +311,11 @@ int agilent_82357a_write_registers(agilent_82357a_private_t *a_priv, const struc
 	if(in_data == NULL)
 	{
 		printk("%s: kmalloc failed\n", __FILE__);
+		up(&a_priv->bulk_transfer_lock);
 		return -ENOMEM;
 	}
 	retval = agilent_82357a_receive_bulk_msg(a_priv, in_data, in_data_length, &bytes_read, 1000);
+	up(&a_priv->bulk_transfer_lock);
 	if(retval)
 	{
 		printk("%s: %s: agilent_82357a_receive_bulk_msg returned %i, bytes_read=%i\n", __FILE__, __FUNCTION__, retval, bytes_read);
@@ -301,13 +332,13 @@ int agilent_82357a_write_registers(agilent_82357a_private_t *a_priv, const struc
 	{
 		printk("%s: %s: nonzero error code 0x%x in DATA_PIPE_CMD_WR_REGS response\n", __FILE__, __FUNCTION__, in_data[1]);
 		return -EIO;
-	}	
+	}
 	kfree(in_data);
 	return 0;
 }
 
-int agilent_82357a_read_registers(agilent_82357a_private_t *a_priv, struct agilent_82357a_register_pairlet *reads, 
-	int num_reads)
+int agilent_82357a_read_registers(agilent_82357a_private_t *a_priv, struct agilent_82357a_register_pairlet *reads,
+	int num_reads, int blocking)
 {
 	int retval;
 	uint8_t *out_data, *in_data;
@@ -317,7 +348,7 @@ int agilent_82357a_read_registers(agilent_82357a_private_t *a_priv, struct agile
 	int j;
 	static const int header_length = 2;
 	static const int max_reads = 62;
-	
+
 	if(num_reads > max_reads)
 	{
 		printk("%s: %s: bug! num_reads=%i too large\n", __FILE__, __FUNCTION__, num_reads);
@@ -325,26 +356,44 @@ int agilent_82357a_read_registers(agilent_82357a_private_t *a_priv, struct agile
 	out_data_length = num_reads + header_length;
 	out_data = kmalloc(out_data_length, GFP_KERNEL);
 	if(out_data == NULL)
-	{	
+	{
 		printk("%s: %s: kmalloc failed\n", __FILE__, __FUNCTION__);
 		return -ENOMEM;
 	}
 	out_data[i++] = DATA_PIPE_CMD_RD_REGS;
 	out_data[i++] = num_reads;
 	for(j = 0; j < num_reads; j++)
-	{	
+	{
 		out_data[i++] = reads[j].address;
-	}	
+	}
 	if(i > out_data_length)
 	{
 		printk("%s: bug! buffer overrun\n", __FUNCTION__);
 	}
+	if(blocking)
+	{
+		retval = down_interruptible(&a_priv->bulk_transfer_lock);
+		if(retval)
+		{
+			kfree(out_data);
+			return retval;
+		}
+	}else
+	{
+		retval = down_trylock(&a_priv->bulk_transfer_lock);
+		if(retval)
+		{
+			kfree(out_data);
+			return -EAGAIN;
+		}
+	}
 	retval = agilent_82357a_send_bulk_msg(a_priv, out_data, i, &bytes_written, 1000);
 	kfree(out_data);
 	if(retval)
 	{
-		printk("%s: %s: agilent_82357a_send_bulk_msg returned %i, bytes_written=%i, i=%i\n", __FILE__, __FUNCTION__, 
-			retval, bytes_written, i);		
+		printk("%s: %s: agilent_82357a_send_bulk_msg returned %i, bytes_written=%i, i=%i\n", __FILE__, __FUNCTION__,
+			retval, bytes_written, i);
+		up(&a_priv->bulk_transfer_lock);
 		return retval;
 	}
 	in_data_length = 0x20;
@@ -352,9 +401,11 @@ int agilent_82357a_read_registers(agilent_82357a_private_t *a_priv, struct agile
 	if(in_data == NULL)
 	{
 		printk("%s: kmalloc failed\n", __FILE__);
+		up(&a_priv->bulk_transfer_lock);
 		return -ENOMEM;
 	}
 	retval = agilent_82357a_receive_bulk_msg(a_priv, in_data, in_data_length, &bytes_read, 10000);
+	up(&a_priv->bulk_transfer_lock);
 	if(retval)
 	{
 		printk("%s: %s: agilent_82357a_receive_bulk_msg returned %i, bytes_read=%i\n", __FILE__, __FUNCTION__, retval, bytes_read);
@@ -372,7 +423,7 @@ int agilent_82357a_read_registers(agilent_82357a_private_t *a_priv, struct agile
 	{
 		printk("%s: %s: nonzero error code 0x%x in DATA_PIPE_CMD_RD_REGS response\n", __FILE__, __FUNCTION__, in_data[1]);
 		return -EIO;
-	}	
+	}
 	for(j = 0; j < num_reads; j++)
 	{
 		reads[j].value = in_data[i++];
@@ -386,10 +437,10 @@ static int agilent_82357a_abort(agilent_82357a_private_t *a_priv, int flush)
 	int retval;
 	uint16_t wIndex = 0;
 	uint8_t status_data[2];
-		
+
 	if(flush)
 		wIndex |= XA_FLUSH;
-	retval = agilent_82357a_receive_control_msg(a_priv, agilent_82357a_control_request, USB_DIR_IN | USB_TYPE_VENDOR | USB_RECIP_DEVICE, 
+	retval = agilent_82357a_receive_control_msg(a_priv, agilent_82357a_control_request, USB_DIR_IN | USB_TYPE_VENDOR | USB_RECIP_DEVICE,
 		XFER_ABORT, wIndex, status_data, sizeof(status_data), 100);
 	if(retval < 0)
 	{
@@ -429,8 +480,9 @@ ssize_t agilent_82357a_read(gpib_board_t *board, uint8_t *buffer, size_t length,
 	uint8_t trailing_flags;
 	unsigned long start_jiffies = jiffies;
 	long jiffie_timeout;
-		
+	
 	*nbytes = 0;
+	*end = 0;
 	out_data_length = 0x9;
 	out_data = kmalloc(out_data_length, GFP_KERNEL);
 	if(out_data == NULL) return -ENOMEM;
@@ -447,21 +499,32 @@ ssize_t agilent_82357a_read(gpib_board_t *board, uint8_t *buffer, size_t length,
 	out_data[i++] = (length >> 24) & 0xff;
 	out_data[i++] = a_priv->eos_char;
 	jiffie_timeout = usec_to_jiffies(board->usec_timeout);
+	retval = down_interruptible(&a_priv->bulk_transfer_lock);
+	if(retval)
+	{
+		kfree(out_data);
+		return retval;
+	}
 	retval = agilent_82357a_send_bulk_msg(a_priv, out_data, i, &bytes_written, jiffies_to_msecs(jiffie_timeout));
 	kfree(out_data);
 	if(retval || bytes_written != i)
 	{
 		printk("%s: agilent_82357a_send_bulk_msg returned %i, bytes_written=%i, i=%i\n", __FILE__, retval, bytes_written, i);
+		up(&a_priv->bulk_transfer_lock);
 		if(retval < 0) return retval;
 		return -EIO;
 	}
 	in_data_length = length + 1;
 	in_data = kmalloc(in_data_length, GFP_KERNEL);
-	if(in_data == NULL) return -ENOMEM;
+	if(in_data == NULL)
+	{
+		up(&a_priv->bulk_transfer_lock);
+		return -ENOMEM;
+	}
 	jiffie_timeout = usec_to_jiffies(board->usec_timeout) - (jiffies - start_jiffies);
 	if(jiffie_timeout > 0)
 	{
-		retval = agilent_82357a_receive_bulk_msg(a_priv, in_data, in_data_length, 
+		retval = agilent_82357a_receive_bulk_msg(a_priv, in_data, in_data_length,
 			&bytes_read, jiffies_to_msecs(jiffie_timeout));
 	}else
 	{
@@ -471,36 +534,43 @@ ssize_t agilent_82357a_read(gpib_board_t *board, uint8_t *buffer, size_t length,
 	if(retval == -ETIMEDOUT)
 	{
 		int extra_bytes_read;
+		int extra_bytes_retval;
 		agilent_82357a_abort(a_priv, 1);
-		retval = agilent_82357a_receive_bulk_msg(a_priv, in_data + bytes_read, in_data_length - bytes_read, 
+		extra_bytes_retval = agilent_82357a_receive_bulk_msg(a_priv, in_data + bytes_read, in_data_length - bytes_read,
 			&extra_bytes_read, 100);
-		printk("%s: %s: agilent_82357a_receive_bulk_msg timed out, bytes_read=%i, extra_bytes_read=%i\n", 
+		printk("%s: %s: agilent_82357a_receive_bulk_msg timed out, bytes_read=%i, extra_bytes_read=%i\n",
 			__FILE__, __FUNCTION__, bytes_read, extra_bytes_read);
 		bytes_read += extra_bytes_read;
-	}
-	if(retval || bytes_read == 0)
+		if(extra_bytes_retval)
+		{
+			printk("%s: %s: extra_bytes_retval=%i, bytes_read=%i\n", __FILE__, __FUNCTION__,
+				extra_bytes_retval, bytes_read);
+			agilent_82357a_abort(a_priv, 0);
+		}
+	}else if(retval)
 	{
-		printk("%s: %s: agilent_82357a_receive_bulk_msg returned %i, bytes_read=%i\n", __FILE__, __FUNCTION__, retval, bytes_read);		
-		kfree(in_data);
+		printk("%s: %s: agilent_82357a_receive_bulk_msg returned %i, bytes_read=%i\n", __FILE__, __FUNCTION__,
+			retval, bytes_read);
 		agilent_82357a_abort(a_priv, 0);
-		if(retval < 0) return retval;
-		return -EIO;
 	}
+	up(&a_priv->bulk_transfer_lock);
 	if(bytes_read > length + 1)
 	{
 		bytes_read = length + 1;
 		printk("%s: %s: bytes_read > length? truncating", __FILE__, __FUNCTION__);
 	}
-	memcpy(buffer, in_data, bytes_read - 1);
 	//printk("%s: %s: received response:\n", __FILE__, __FUNCTION__);
 	//agilent_82357a_dump_raw_block(in_data, in_data_length);
-	trailing_flags = in_data[bytes_read - 1];
+	if(bytes_read >= 1)
+	{
+		memcpy(buffer, in_data, bytes_read - 1);
+		trailing_flags = in_data[bytes_read - 1];
+		*nbytes = bytes_read - 1;
+		if(trailing_flags & (ATRF_EOI | ATRF_EOS)) *end = 1;
+	}
 	kfree(in_data);
-	*nbytes = bytes_read - 1;
-	if(trailing_flags & (ATRF_EOI | ATRF_EOS)) *end = 1;
-	else *end = 0;
 	//FIXME check trailing flags for error
-	return 0;
+	return retval;
 }
 
 static ssize_t agilent_82357a_generic_write(gpib_board_t *board, uint8_t *buffer, size_t length, int send_commands, int send_eoi)
@@ -508,14 +578,13 @@ static ssize_t agilent_82357a_generic_write(gpib_board_t *board, uint8_t *buffer
 	int retval;
 	agilent_82357a_private_t *a_priv = board->private_data;
 	uint8_t *out_data;
-	uint8_t status_data[0x8];;
-	int out_data_length;	
+	uint8_t status_data[0x8];
+	int out_data_length;
 	int bytes_written;
 	int i = 0, j;
 	unsigned int bytes_completed;
 	long jiffie_timeout;
-	int write_aborted = 0;
-	
+
 	out_data_length = length + 0x8;
 	out_data = kmalloc(out_data_length, GFP_KERNEL);
 	if(out_data == NULL) return -ENOMEM;
@@ -526,7 +595,7 @@ static ssize_t agilent_82357a_generic_write(gpib_board_t *board, uint8_t *buffer
 	if(send_commands)
 		out_data[i] |= AWF_ATN | AWF_NO_FAST_TALKER;
 	if(send_eoi)
-		out_data[i] |= AWF_SEND_EOI;	
+		out_data[i] |= AWF_SEND_EOI;
 	++i;
 	out_data[i++] = length & 0xff;
 	out_data[i++] = (length >> 8) & 0xff;
@@ -537,17 +606,20 @@ static ssize_t agilent_82357a_generic_write(gpib_board_t *board, uint8_t *buffer
 	//printk("%s: sending bulk msg(), send_commands=%i\n", __FUNCTION__, send_commands);
 	clear_bit(AIF_WRITE_COMPLETE_BN, &a_priv->interrupt_flags);
 	jiffie_timeout = usec_to_jiffies(board->usec_timeout);
+	retval = down_interruptible(&a_priv->bulk_transfer_lock);
+	if(retval)
+	{
+		kfree(out_data);
+		return retval;
+	}
 	retval = agilent_82357a_send_bulk_msg(a_priv, out_data, i, &bytes_written, jiffies_to_msecs(jiffie_timeout));
 	kfree(out_data);
-	if(retval == -ETIMEDOUT)
+	if(retval || bytes_written != i)
 	{
 		agilent_82357a_abort(a_priv, 0);
-		write_aborted = 1;
-		printk("%s: %s: agilent_82357a_send_bulk_msg timed out, bytes_written=%i\n", 
-			__FILE__, __FUNCTION__, bytes_written);
-	}else if(retval || bytes_written != i)
-	{
 		printk("%s: agilent_82357a_send_bulk_msg returned %i, bytes_written=%i, i=%i\n", __FILE__, retval, bytes_written, i);
+		up(&a_priv->bulk_transfer_lock);
+		if(retval < 0) return retval;
 		return -EIO;
 	}
 	//printk("%s: waiting for write complete\n", __FUNCTION__);
@@ -556,16 +628,18 @@ static ssize_t agilent_82357a_generic_write(gpib_board_t *board, uint8_t *buffer
 	if(retval)
 	{
 		printk("%s: %s: wait interrupted\n", __FILE__, __FUNCTION__);
+		agilent_82357a_abort(a_priv, 0);
+		up(&a_priv->bulk_transfer_lock);
 		return -ERESTARTSYS;
 	}
-	if(test_bit(AIF_WRITE_COMPLETE_BN, &a_priv->interrupt_flags) == 0 && write_aborted == 0)
+	if(test_bit(AIF_WRITE_COMPLETE_BN, &a_priv->interrupt_flags) == 0)
 	{
 		agilent_82357a_abort(a_priv, 0);
-		write_aborted = 1;
 	}
 	//printk("%s: receiving control msg\n", __FUNCTION__);
-	retval = agilent_82357a_receive_control_msg(a_priv, agilent_82357a_control_request, USB_DIR_IN | USB_TYPE_VENDOR | USB_RECIP_DEVICE, 
+	retval = agilent_82357a_receive_control_msg(a_priv, agilent_82357a_control_request, USB_DIR_IN | USB_TYPE_VENDOR | USB_RECIP_DEVICE,
 		XFER_STATUS, 0, status_data, sizeof(status_data), 100);
+	up(&a_priv->bulk_transfer_lock);
 	if(retval < 0)
 	{
 		printk("%s: %s: agilent_82357a_receive_control_msg() returned %i\n", __FILE__, __FUNCTION__, retval);
@@ -595,7 +669,7 @@ int agilent_82357a_take_control(gpib_board_t *board, int synchronous)
 //	const int timeout = 1000;
 	struct agilent_82357a_register_pairlet write;
 	int retval;
-	
+
 	write.address = AUXCR;
 	if(synchronous)
 	{
@@ -630,7 +704,7 @@ int agilent_82357a_go_to_standby(gpib_board_t *board)
 	agilent_82357a_private_t *a_priv = board->private_data;
 	struct agilent_82357a_register_pairlet write;
 	int retval;
-	
+
 	write.address = AUXCR;
 	write.value = AUX_GTS;
 	retval = agilent_82357a_write_registers(a_priv, &write, 1);
@@ -648,7 +722,7 @@ void agilent_82357a_request_system_control(gpib_board_t *board, int request_cont
 	struct agilent_82357a_register_pairlet writes[2];
 	int retval;
 	int i = 0;
-		
+
 //	writes[i].address = AUXCR;
 	if(request_control)
 	{
@@ -657,7 +731,7 @@ void agilent_82357a_request_system_control(gpib_board_t *board, int request_cont
 	}else
 	{
 //		writes[i].value = AUX_RLC;
-		a_priv->bogus_ibsta &= ~CIC;
+		a_priv->is_cic = 0;
 		a_priv->hw_control_bits &= ~SYSTEM_CONTROLLER;
 	}
 //	++i;
@@ -676,13 +750,13 @@ void agilent_82357a_interface_clear(gpib_board_t *board, int assert)
 	agilent_82357a_private_t *a_priv = board->private_data;
 	struct agilent_82357a_register_pairlet write;
 	int retval;
-		
+
 	write.address = AUXCR;
 	write.value = AUX_SIC;
 	if(assert)
 	{
 		write.value |= AUX_CS;
-		a_priv->bogus_ibsta |= CIC;
+		a_priv->is_cic = 1;
 	}
 	retval = agilent_82357a_write_registers(a_priv, &write, 1);
 	if(retval)
@@ -696,7 +770,7 @@ void agilent_82357a_remote_enable(gpib_board_t *board, int enable)
 	agilent_82357a_private_t *a_priv = board->private_data;
 	struct agilent_82357a_register_pairlet write;
 	int retval;
-		
+
 	write.address = AUXCR;
 	write.value = AUX_SRE;
 	if(enable)
@@ -710,22 +784,25 @@ void agilent_82357a_remote_enable(gpib_board_t *board, int enable)
 	}
 	return;// 0;
 }
-//FIXME need to be able to return error
-void agilent_82357a_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits)
+
+int agilent_82357a_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits)
 {
 	agilent_82357a_private_t *a_priv = board->private_data;
-	
-	a_priv->eos_char = eos_byte;
-	a_priv->eos_mode = REOS | BIN;
+
 	if(compare_8_bits == 0)
 	{
-		printk("%s: %s: warning: hardware only supports 8-bit EOS compare", __FILE__, __FUNCTION__);
+		printk("%s: %s: hardware only supports 8-bit EOS compare", __FILE__, __FUNCTION__);
+		return -EOPNOTSUPP;
 	}
+	a_priv->eos_char = eos_byte;
+	a_priv->eos_mode = REOS | BIN;
+	return 0;
 }
+
 void agilent_82357a_disable_eos(gpib_board_t *board)
 {
 	agilent_82357a_private_t *a_priv = board->private_data;
-	
+
 	a_priv->eos_mode &= ~REOS;
 }
 
@@ -734,16 +811,20 @@ unsigned int agilent_82357a_update_status( gpib_board_t *board, unsigned int cle
 	agilent_82357a_private_t *a_priv = board->private_data;
 	struct agilent_82357a_register_pairlet address_status;
 	int retval;
-	unsigned long status = a_priv->bogus_ibsta;
-	
+	unsigned long status;
+
 	board->status &= ~clear_mask;
-	
+	status = board->status;
+	if(a_priv->is_cic)
+		status |= CIC;
+	else
+		status &= ~CIC;
 	address_status.address = ADSR;
-	retval = agilent_82357a_read_registers(a_priv, &address_status, 1);
+	retval = agilent_82357a_read_registers(a_priv, &address_status, 1, 0);
 	if(retval)
 	{
 		printk("%s: %s: agilent_82357a_read_registers() returned error\n", __FILE__, __FUNCTION__);
-		return 0;
+		return status;
 	}
 	// check for remote/local
 	if(address_status.value & HR_REM)
@@ -782,7 +863,7 @@ void agilent_82357a_primary_address(gpib_board_t *board, unsigned int address)
 	agilent_82357a_private_t *a_priv = board->private_data;
 	struct agilent_82357a_register_pairlet write;
 	int retval;
-	
+
 	// put primary address in address0
 	write.address = ADR;
 	write.value = address & ADDRESS_MASK;
@@ -822,7 +903,7 @@ int agilent_82357a_parallel_poll(gpib_board_t *board, uint8_t *result)
 	}
 	udelay(2);	//silly, since usb write will take way longer
 	read.address = CPTR;
-	retval = agilent_82357a_read_registers(a_priv, &read, 1);
+	retval = agilent_82357a_read_registers(a_priv, &read, 1, 1);
 	if(retval)
 	{
 		printk("%s: %s: agilent_82357a_read_registers() returned error\n", __FILE__, __FUNCTION__);
@@ -875,7 +956,7 @@ int agilent_82357a_line_status( const gpib_board_t *board )
 	int status = ValidALL;
 
 	bus_status.address = BSR;
-	retval = agilent_82357a_read_registers(a_priv, &bus_status, 1);
+	retval = agilent_82357a_read_registers(a_priv, &bus_status, 1, 0);
 	if(retval)
 	{
 		printk("%s: %s: agilent_82357a_read_registers() returned error\n", __FILE__, __FUNCTION__);
@@ -906,7 +987,7 @@ static unsigned short nanosec_to_fast_talker_bits(unsigned int *nanosec)
 	static const int max_value = 0x72;
 	static const int min_value = 0x11;
 	unsigned short bits;
-	
+
 	bits = (*nanosec + nanosec_per_bit / 2) / nanosec_per_bit;
 	if(bits < min_value) bits = min_value;
 	if(bits > max_value) bits = max_value;
@@ -919,7 +1000,7 @@ unsigned int agilent_82357a_t1_delay( gpib_board_t *board, unsigned int nanosec
 	agilent_82357a_private_t *a_priv = board->private_data;
 	struct agilent_82357a_register_pairlet write;
 	int retval;
-	
+
 	write.address = FAST_TALKER_T1;
 	write.value = nanosec_to_fast_talker_bits(&nanosec);
 	retval = agilent_82357a_write_registers(a_priv, &write, 1);
@@ -939,12 +1020,12 @@ void agilent_82357a_interrupt_complete(struct urb *urb, struct pt_regs *regs)
 	unsigned long interrupt_flags;
 #if 0
 	int i;
-	
+
 	printk("debug: %s: %s: status=0x%x, error_count=%i, actual_length=%i transfer_buffer:\n", __FILE__, __FUNCTION__,
-		urb->status, urb->error_count, urb->actual_length); 
+		urb->status, urb->error_count, urb->actual_length);
 	for(i = 0; i < urb->actual_length; ++i)
 	{
-		printk("%2x ", transfer_buffer[i]); 
+		printk("%2x ", transfer_buffer[i]);
 	}
 	printk("\n");
 #endif
@@ -956,7 +1037,7 @@ void agilent_82357a_interrupt_complete(struct urb *urb, struct pt_regs *regs)
 	if(test_bit(AIF_WRITE_COMPLETE_BN, &interrupt_flags))
 		set_bit(AIF_WRITE_COMPLETE_BN, &a_priv->interrupt_flags);
 	if(test_bit(AIF_SRQ_BN, &interrupt_flags))
-		set_bit(AIF_SRQ_BN, &a_priv->interrupt_flags);
+		set_bit(SRQI_NUM, &board->status);
 	retval = usb_submit_urb(a_priv->interrupt_urb, GFP_ATOMIC);
 	if(retval)
 	{
@@ -971,34 +1052,34 @@ static int agilent_82357a_setup_urbs(gpib_board_t *board)
 	struct usb_device *usb_dev;
 	int int_pipe;
 	int retval;
-	
-	retval = down_interruptible(&a_priv->interrupt_transfer_lock);
+
+	retval = down_interruptible(&a_priv->interrupt_alloc_lock);
 	if(retval) return retval;
 	if(a_priv->bus_interface == NULL)
 	{
-		up(&a_priv->interrupt_transfer_lock);
+		up(&a_priv->interrupt_alloc_lock);
 		return -ENODEV;
 	}
 	a_priv->interrupt_urb = usb_alloc_urb(0, GFP_KERNEL);
 	if(a_priv->interrupt_urb == NULL)
 	{
-		up(&a_priv->interrupt_transfer_lock);
+		up(&a_priv->interrupt_alloc_lock);
 		return -ENOMEM;
 	}
 	usb_dev = interface_to_usbdev(a_priv->bus_interface);
 	int_pipe = usb_rcvintpipe(usb_dev, AGILENT_82357A_INTERRUPT_IN_ENDPOINT);
-	usb_fill_int_urb(a_priv->interrupt_urb, usb_dev, int_pipe, a_priv->interrupt_buffer, 
+	usb_fill_int_urb(a_priv->interrupt_urb, usb_dev, int_pipe, a_priv->interrupt_buffer,
 		sizeof(a_priv->interrupt_buffer), agilent_82357a_interrupt_complete, board, 1);
 	retval = usb_submit_urb(a_priv->interrupt_urb, GFP_KERNEL);
-	if(retval) 
+	if(retval)
 	{
 		usb_free_urb(a_priv->interrupt_urb);
 		a_priv->interrupt_urb = NULL;
 		printk("%s: failed to submit first interrupt urb, retval=%i\n", __FILE__, retval);
-		up(&a_priv->interrupt_transfer_lock);
+		up(&a_priv->interrupt_alloc_lock);
 		return retval;
 	}
-	up(&a_priv->interrupt_transfer_lock);
+	up(&a_priv->interrupt_alloc_lock);
 	return 0;
 }
 
@@ -1008,7 +1089,7 @@ static int agilent_82357a_reset_usb_configuration(gpib_board_t *board)
 	agilent_82357a_private_t *a_priv = board->private_data;
 	struct usb_device *usb_dev;
 	int retval;
-	
+
 	if(a_priv->bus_interface == NULL)
 	{
 		return -ENODEV;
@@ -1044,8 +1125,9 @@ static int agilent_82357a_allocate_private(gpib_board_t *board)
 	a_priv = board->private_data;
 	memset(a_priv, 0, sizeof(agilent_82357a_private_t));
 	init_MUTEX(&a_priv->bulk_transfer_lock);
-	init_MUTEX(&a_priv->control_transfer_lock);
-	init_MUTEX(&a_priv->interrupt_transfer_lock);
+	init_MUTEX(&a_priv->bulk_alloc_lock);
+	init_MUTEX(&a_priv->control_alloc_lock);
+	init_MUTEX(&a_priv->interrupt_alloc_lock);
 	return 0;
 }
 
@@ -1065,7 +1147,7 @@ static int agilent_82357a_init(gpib_board_t *board)
 	int retval;
 	int i;
 	unsigned int nanosec;
-	
+
 	i = 0;
 	writes[i].address = LED_CONTROL;
 	writes[i].value = FAIL_LED_ON;
@@ -1152,7 +1234,7 @@ static int agilent_82357a_init(gpib_board_t *board)
 		return -EIO;
 	}
 	hw_control.address = HW_CONTROL;
-	retval = agilent_82357a_read_registers(a_priv, &hw_control, 1);
+	retval = agilent_82357a_read_registers(a_priv, &hw_control, 1, 1);
 	if(retval)
 	{
 		printk("%s: %s: agilent_82357a_read_registers() returned error\n", __FILE__, __FUNCTION__);
@@ -1168,7 +1250,7 @@ int agilent_82357a_attach(gpib_board_t *board, gpib_board_config_t config)
 	int retval;
 	int i;
 	agilent_82357a_private_t *a_priv;
-	
+
 	if(down_interruptible(&agilent_82357a_hotplug_lock))
 		return -ERESTARTSYS;
 	//printk("%s: enter\n", __FUNCTION__);
@@ -1197,23 +1279,23 @@ int agilent_82357a_attach(gpib_board_t *board, gpib_board_config_t config)
 		printk("No NI usb-b gpib adapters found, have you loaded its firmware?\n");
 		return -ENODEV;
 	}
-#if 0	
+#if 0
 	retval = agilent_82357a_reset_usb_configuration(board);
-	if(retval < 0) 
+	if(retval < 0)
 	{
 		up(&agilent_82357a_hotplug_lock);
 		return retval;
 	}
 #endif
 	retval = agilent_82357a_setup_urbs(board);
-	if(retval < 0) 
+	if(retval < 0)
 	{
 		up(&agilent_82357a_hotplug_lock);
 		return retval;
 	}
 	//printk("%s: finished setup_urbs()()\n", __FUNCTION__);
 	retval = agilent_82357a_init(board);
-	if(retval < 0) 
+	if(retval < 0)
 	{
 		up(&agilent_82357a_hotplug_lock);
 		return retval;
@@ -1230,7 +1312,7 @@ static int agilent_82357a_go_idle(gpib_board_t *board)
 	struct agilent_82357a_register_pairlet writes[0x20];
 	int retval;
 	int i;
-	
+
 	i = 0;
 	// turn on tms9914 reset state
 	writes[i].address = AUXCR;
@@ -1269,7 +1351,7 @@ static int agilent_82357a_go_idle(gpib_board_t *board)
 void agilent_82357a_detach(gpib_board_t *board)
 {
 	agilent_82357a_private_t *a_priv;
-	
+
 	down(&agilent_82357a_hotplug_lock);
 	//printk("%s: enter\n", __FUNCTION__);
 	a_priv = board->private_data;
@@ -1280,9 +1362,9 @@ void agilent_82357a_detach(gpib_board_t *board)
 			agilent_82357a_go_idle(board);
 			usb_set_intfdata(a_priv->bus_interface, NULL);
 		}
-		down(&a_priv->control_transfer_lock);
-		down(&a_priv->bulk_transfer_lock);
-		down(&a_priv->interrupt_transfer_lock);
+		down(&a_priv->control_alloc_lock);
+		down(&a_priv->bulk_alloc_lock);
+		down(&a_priv->interrupt_alloc_lock);
 		agilent_82357a_cleanup_urbs(a_priv);
 		agilent_82357a_free_private(a_priv);
 	}
@@ -1292,47 +1374,48 @@ void agilent_82357a_detach(gpib_board_t *board)
 
 gpib_interface_t agilent_82357a_gpib_interface =
 {
-	name: "agilent_82357a",
-	attach: agilent_82357a_attach,
-	detach: agilent_82357a_detach,
-	read: agilent_82357a_read,
-	write: agilent_82357a_write,
-	command: agilent_82357a_command,
-	take_control: agilent_82357a_take_control,
-	go_to_standby: agilent_82357a_go_to_standby,
-	request_system_control: agilent_82357a_request_system_control,
-	interface_clear: agilent_82357a_interface_clear,
-	remote_enable: agilent_82357a_remote_enable,
-	enable_eos: agilent_82357a_enable_eos,
-	disable_eos: agilent_82357a_disable_eos,
-	parallel_poll: agilent_82357a_parallel_poll,
-	parallel_poll_configure: agilent_82357a_parallel_poll_configure,
-	parallel_poll_response: agilent_82357a_parallel_poll_response,
-	line_status: agilent_82357a_line_status,
-	update_status: agilent_82357a_update_status,
-	primary_address: agilent_82357a_primary_address,
-	secondary_address: agilent_82357a_secondary_address,
-	serial_poll_response: agilent_82357a_serial_poll_response,
-	serial_poll_status: agilent_82357a_serial_poll_status,
-	t1_delay: agilent_82357a_t1_delay,
-	return_to_local: agilent_82357a_return_to_local,
+	.name = "agilent_82357a",
+	.attach = agilent_82357a_attach,
+	.detach = agilent_82357a_detach,
+	.read = agilent_82357a_read,
+	.write = agilent_82357a_write,
+	.command = agilent_82357a_command,
+	.take_control = agilent_82357a_take_control,
+	.go_to_standby = agilent_82357a_go_to_standby,
+	.request_system_control = agilent_82357a_request_system_control,
+	.interface_clear = agilent_82357a_interface_clear,
+	.remote_enable = agilent_82357a_remote_enable,
+	.enable_eos = agilent_82357a_enable_eos,
+	.disable_eos = agilent_82357a_disable_eos,
+	.parallel_poll = agilent_82357a_parallel_poll,
+	.parallel_poll_configure = agilent_82357a_parallel_poll_configure,
+	.parallel_poll_response = agilent_82357a_parallel_poll_response,
+	.line_status = agilent_82357a_line_status,
+	.update_status = agilent_82357a_update_status,
+	.primary_address = agilent_82357a_primary_address,
+	.secondary_address = agilent_82357a_secondary_address,
+	.serial_poll_response = agilent_82357a_serial_poll_response,
+	.serial_poll_status = agilent_82357a_serial_poll_status,
+	.t1_delay = agilent_82357a_t1_delay,
+	.return_to_local = agilent_82357a_return_to_local,
+	.no_7_bit_eos = 1
 };
 
 // Table with the USB-devices: just now only testing IDs
-static struct usb_device_id agilent_82357a_driver_device_table [] = 
+static struct usb_device_id agilent_82357a_driver_device_table [] =
 {
 	{USB_DEVICE(USB_VENDOR_ID_AGILENT, USB_DEVICE_ID_AGILENT_82357A)},
 	{} /* Terminating entry */
 };
 MODULE_DEVICE_TABLE(usb, agilent_82357a_driver_device_table);
 
-static int agilent_82357a_driver_probe(struct usb_interface *interface, 
-	const struct usb_device_id *id) 
+static int agilent_82357a_driver_probe(struct usb_interface *interface,
+	const struct usb_device_id *id)
 {
 	int i;
 	char *path;
 	static const int pathLength = 1024;
-	
+
 //	printk("agilent_82357a_driver_probe\n");
 	if(down_interruptible(&agilent_82357a_hotplug_lock))
 		return -ERESTARTSYS;
@@ -1343,7 +1426,7 @@ static int agilent_82357a_driver_probe(struct usb_interface *interface,
 		{
 			agilent_82357a_driver_interfaces[i] = interface;
 			usb_set_intfdata(interface, NULL);
-//			printk("set bus interface %i to address 0x%p\n", i, interface);	
+//			printk("set bus interface %i to address 0x%p\n", i, interface);
 			break;
 		}
 	}
@@ -1355,7 +1438,7 @@ static int agilent_82357a_driver_probe(struct usb_interface *interface,
 		return -1;
 	}
 	path = kmalloc(pathLength, GFP_KERNEL);
-	if(path == NULL) 
+	if(path == NULL)
 	{
 		usb_put_dev(interface_to_usbdev(interface));
 		up(&agilent_82357a_hotplug_lock);
@@ -1368,10 +1451,10 @@ static int agilent_82357a_driver_probe(struct usb_interface *interface,
 	return 0;
 }
 
-static void agilent_82357a_driver_disconnect(struct usb_interface *interface) 
+static void agilent_82357a_driver_disconnect(struct usb_interface *interface)
 {
 	int i;
-	
+
 	down(&agilent_82357a_hotplug_lock);
 //	printk("%s: enter\n", __FUNCTION__);
 	for(i = 0; i < MAX_NUM_82357A_INTERFACES; ++i)
@@ -1379,22 +1462,22 @@ static void agilent_82357a_driver_disconnect(struct usb_interface *interface)
 		if(agilent_82357a_driver_interfaces[i] == interface)
 		{
 			gpib_board_t *board = usb_get_intfdata(interface);
-			
+
 			if(board)
 			{
 				agilent_82357a_private_t *a_priv = board->private_data;
 				if(a_priv)
 				{
-					down(&a_priv->control_transfer_lock);
-					down(&a_priv->bulk_transfer_lock);
-					down(&a_priv->interrupt_transfer_lock);
+					down(&a_priv->control_alloc_lock);
+					down(&a_priv->bulk_alloc_lock);
+					down(&a_priv->interrupt_alloc_lock);
 					agilent_82357a_cleanup_urbs(a_priv);
 					a_priv->bus_interface = NULL;
-					up(&a_priv->interrupt_transfer_lock);
-					up(&a_priv->bulk_transfer_lock);
-					up(&a_priv->control_transfer_lock);
+					up(&a_priv->interrupt_alloc_lock);
+					up(&a_priv->bulk_alloc_lock);
+					up(&a_priv->control_alloc_lock);
 				}
-			}	
+			}
 //			printk("nulled agilent_82357a_driver_interfaces[%i]\n", i);
 			agilent_82357a_driver_interfaces[i] = NULL;
 			break;
@@ -1409,7 +1492,7 @@ static void agilent_82357a_driver_disconnect(struct usb_interface *interface)
 	up(&agilent_82357a_hotplug_lock);
 }
 
-static struct usb_driver agilent_82357a_bus_driver = 
+static struct usb_driver agilent_82357a_bus_driver =
 {
 	.owner = &__this_module,
 	.name = "agilent_82357a_gpib",
@@ -1421,7 +1504,7 @@ static struct usb_driver agilent_82357a_bus_driver =
 static int agilent_82357a_init_module(void)
 {
 	int i;
-	
+
 	info("agilent_82357a_gpib driver loading");
 	for(i = 0; i < MAX_NUM_82357A_INTERFACES; ++i)
 		agilent_82357a_driver_interfaces[i] = NULL;
