@@ -31,6 +31,7 @@
 #include <linux/slab.h>
 #include <linux/string.h>
 #include <linux/timer.h>
+#include <linux/version.h>
 #include <linux/module.h>
 #include <asm/io.h>
 #include <asm/system.h>
@@ -56,8 +57,6 @@
 
 #ifdef PCMCIA_DEBUG
 static int pc_debug = PCMCIA_DEBUG;
-static char *version =
-"cb7210_cs.c 0.11";
 #endif
 
 /*====================================================================*/
@@ -234,11 +233,13 @@ static dev_link_t *gpib_attach(void)
 	dev_list = link;
 	client_reg.dev_info = &dev_info;
 	client_reg.Attributes = INFO_IO_CLIENT | INFO_CARD_SHARE;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13)
 	client_reg.EventMask =
-	CS_EVENT_CARD_INSERTION | CS_EVENT_CARD_REMOVAL |
-	CS_EVENT_RESET_PHYSICAL | CS_EVENT_CARD_RESET |
-	CS_EVENT_PM_SUSPEND | CS_EVENT_PM_RESUME;
+		CS_EVENT_CARD_INSERTION | CS_EVENT_CARD_REMOVAL |
+		CS_EVENT_RESET_PHYSICAL | CS_EVENT_CARD_RESET |
+		CS_EVENT_PM_SUSPEND | CS_EVENT_PM_RESUME;
 	client_reg.event_handler = &gpib_event;
+#endif	
 	client_reg.Version = 0x0210;
 	client_reg.event_callback_args.client_data = link;
 	ret = pcmcia_register_client(&link->handle, &client_reg);
@@ -551,8 +552,11 @@ static int gpib_event(event_t event, int priority,
 /*====================================================================*/
 static struct pcmcia_driver cb_gpib_cs_driver =
 {
-	.attach = gpib_attach,
-	.detach = gpib_detach,
+	.attach = &gpib_attach,
+	.detach = &gpib_detach,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,13)
+	.event = &gpib_event,
+#endif
 	.owner = THIS_MODULE,
 	.drv = {
 		.name = "cb_gpib_cs",
@@ -561,17 +565,6 @@ static struct pcmcia_driver cb_gpib_cs_driver =
 
 int cb_pcmcia_init_module(void)
 {
-    servinfo_t serv;
-#ifdef PCMCIA_DEBUG
-    if (pc_debug)
-	printk(KERN_INFO "%s\n", version);
-#endif
-    pcmcia_get_card_services_info(&serv);
-    if (serv.Revision != CS_RELEASE_CODE) {
-	printk(KERN_NOTICE "gpib: Card Services release "
-	       "does not match!\n");
-	return -1;
-    }
     pcmcia_register_driver(&cb_gpib_cs_driver);
     return 0;
 }
@@ -593,13 +586,41 @@ void cb_pcmcia_cleanup_module(void)
 int cb_pcmcia_attach(gpib_board_t *board, gpib_board_config_t config);
 void cb_pcmcia_detach(gpib_board_t *board);
 
+gpib_interface_t cb_pcmcia_unaccel_interface =
+{
+	name: "cbi_pcmcia_unaccel",
+	attach: cb_pcmcia_attach,
+	detach: cb_pcmcia_detach,
+	read: cb7210_read,
+	write: cb7210_write,
+	command: cb7210_command,
+	take_control: cb7210_take_control,
+	go_to_standby: cb7210_go_to_standby,
+	request_system_control: cb7210_request_system_control,
+	interface_clear: cb7210_interface_clear,
+	remote_enable: cb7210_remote_enable,
+	enable_eos: cb7210_enable_eos,
+	disable_eos: cb7210_disable_eos,
+	parallel_poll: cb7210_parallel_poll,
+	parallel_poll_configure: cb7210_parallel_poll_configure,
+	parallel_poll_response: cb7210_parallel_poll_response,
+	line_status: cb7210_line_status,
+	update_status: cb7210_update_status,
+	primary_address: cb7210_primary_address,
+	secondary_address: cb7210_secondary_address,
+	serial_poll_response: cb7210_serial_poll_response,
+	serial_poll_status: cb7210_serial_poll_status,
+	t1_delay: cb7210_t1_delay,
+	return_to_local: cb7210_return_to_local,
+};
+
 gpib_interface_t cb_pcmcia_interface =
 {
 	name: "cbi_pcmcia",
 	attach: cb_pcmcia_attach,
 	detach: cb_pcmcia_detach,
-	read: cb7210_read,
-	write: cb7210_write,
+	read: cb7210_accel_read,
+	write: cb7210_accel_write,
 	command: cb7210_command,
 	take_control: cb7210_take_control,
 	go_to_standby: cb7210_go_to_standby,
@@ -667,8 +688,8 @@ int cb_pcmcia_attach( gpib_board_t *board, gpib_board_config_t config )
 	cb_priv = board->private_data;
 	nec_priv = &cb_priv->nec7210_priv;
 
-	nec_priv->iobase = dev_list->io.BasePort1;
-	cb_priv->fifo_iobase = nec_priv->iobase;
+	nec_priv->iobase = (void*)(unsigned long)dev_list->io.BasePort1;
+	cb_priv->fifo_iobase = dev_list->io.BasePort1;
 
 	if(request_irq(dev_list->irq.AssignedIRQ, cb7210_interrupt, SA_SHIRQ,
 		"cb7210", board))
