@@ -73,10 +73,10 @@ void cec_remote_enable(gpib_board_t *board, int enable)
 	cec_private_t *priv = board->private_data;
 	nec7210_remote_enable(board, &priv->nec7210_priv, enable);
 }
-void cec_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits)
+int cec_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits)
 {
 	cec_private_t *priv = board->private_data;
-	nec7210_enable_eos(board, &priv->nec7210_priv, eos_byte, compare_8_bits);
+	return nec7210_enable_eos(board, &priv->nec7210_priv, eos_byte, compare_8_bits);
 }
 void cec_disable_eos(gpib_board_t *board)
 {
@@ -255,8 +255,8 @@ int cec_pci_attach(gpib_board_t *board, gpib_board_config_t config)
 
 	cec_priv->plx_iobase = pci_resource_start(cec_priv->pci_device, 1);
 	printk(" plx9050 base address 0x%lx\n", cec_priv->plx_iobase);
-	nec_priv->iobase = pci_resource_start(cec_priv->pci_device, 3);
-	printk(" nec7210 base address 0x%lx\n", nec_priv->iobase);
+	nec_priv->iobase = (void*)(pci_resource_start(cec_priv->pci_device, 3));
+	printk(" nec7210 base address 0x%p\n", nec_priv->iobase);
 
 	isr_flags |= SA_SHIRQ;
 	if(request_irq(cec_priv->pci_device->irq, cec_interrupt, isr_flags, "pci-gpib", board))
@@ -305,7 +305,7 @@ void cec_pci_detach(gpib_board_t *board)
 	cec_free_private(board);
 }
 
-static struct pci_device_id cec_pci_table[] __devinitdata = 
+static const struct pci_device_id cec_pci_table[] = 
 {
 	{CEC_VENDOR_ID, CEC_DEV_ID, PCI_ANY_ID, CEC_SUBID, 0, 0, 0 },
 	{0}
