@@ -77,10 +77,10 @@ void hp_82341_remote_enable( gpib_board_t *board, int enable )
 	hp_82341_private_t *priv = board->private_data;
 	tms9914_remote_enable( board, &priv->tms9914_priv, enable );
 }
-void hp_82341_enable_eos( gpib_board_t *board, uint8_t eos_byte, int compare_8_bits )
+int hp_82341_enable_eos( gpib_board_t *board, uint8_t eos_byte, int compare_8_bits )
 {
 	hp_82341_private_t *priv = board->private_data;
-	tms9914_enable_eos( board, &priv->tms9914_priv, eos_byte, compare_8_bits );
+	return tms9914_enable_eos( board, &priv->tms9914_priv, eos_byte, compare_8_bits );
 }
 void hp_82341_disable_eos( gpib_board_t *board )
 {
@@ -217,12 +217,12 @@ void hp_82341_free_private( gpib_board_t *board )
 
 uint8_t hp_82341_read_byte( tms9914_private_t *priv, unsigned int register_num )
 {
-	return inb(priv->iobase + register_num);
+	return inb((unsigned long)(priv->iobase) + register_num);
 }
 
 void hp_82341_write_byte( tms9914_private_t *priv, uint8_t data, unsigned int register_num )
 {
-	outb(data, priv->iobase + register_num);
+	outb(data, (unsigned long)(priv->iobase) + register_num);
 }
 
 int hp_82341_find_isapnp_board(struct pnp_dev **dev)
@@ -461,7 +461,7 @@ int hp_82341_attach(gpib_board_t *board, gpib_board_config_t config)
 		if(retval < 0)
 			return retval;
 		hp_priv->pnp_dev = dev;
-		board->ibbase = pnp_port_start(dev, 0);
+		board->ibbase = (void*)(pnp_port_start(dev, 0));
 		board->ibirq = pnp_irq(dev, 0);
 		hp_priv->hw_version = HW_VERSION_82341D;
 		hp_priv->io_region_offset = 0x8;
@@ -470,10 +470,10 @@ int hp_82341_attach(gpib_board_t *board, gpib_board_config_t config)
 		hp_priv->hw_version = HW_VERSION_82341C;
 		hp_priv->io_region_offset = 0x400;
 	}	
-	printk("hp_82341: base io 0x%lx\n", board->ibbase);
+	printk("hp_82341: base io 0x%p\n", board->ibbase);
 	for(i = 0; i < hp_82341_num_io_regions; ++i)
 	{
-		start_addr = board->ibbase + i * hp_priv->io_region_offset;
+		start_addr = (unsigned long)(board->ibbase) + i * hp_priv->io_region_offset;
 		if(request_region(start_addr, hp_82341_region_iosize, "hp_82341" ) == NULL)
 		{
 			printk( "hp_82341: failed to allocate io ports 0x%lx-0x%lx\n",
@@ -483,7 +483,7 @@ int hp_82341_attach(gpib_board_t *board, gpib_board_config_t config)
 		}
 		hp_priv->iobase[i] = start_addr;
 	}
-	tms_priv->iobase = hp_priv->iobase[2];
+	tms_priv->iobase = (void*)(hp_priv->iobase[2]);
 	if(hp_priv->hw_version == HW_VERSION_82341D)
 	{
 		retval = isapnp_cfg_begin(hp_priv->pnp_dev->card->number, hp_priv->pnp_dev->number);
@@ -566,7 +566,7 @@ void hp_82341_detach(gpib_board_t *board)
 	hp_82341_free_private( board );
 }
 
-static const struct pnp_device_id hp_82341_pnp_table[] __devinitdata = 
+static const struct pnp_device_id hp_82341_pnp_table[] = 
 {
 	{.id = "HWP1411"},
 	{.id = ""}
