@@ -92,7 +92,7 @@ struct gpib_interface_struct
 	 * 'compare_8_bits' is nonzero, then all 8 bits are compared
 	 * with the eos bytes.  Otherwise only the 7 least significant
 	 * bits are compared. */
-	void (*enable_eos)(gpib_board_t *board, uint8_t eos, int compare_8_bits);
+	int (*enable_eos)(gpib_board_t *board, uint8_t eos, int compare_8_bits);
 	/* disable END on eos byte (END on EOI only)*/
 	void (*disable_eos)(gpib_board_t *board);
 	/* configure parallel poll */
@@ -130,6 +130,8 @@ struct gpib_interface_struct
 	unsigned int ( *t1_delay )( gpib_board_t *board, unsigned int nano_sec );
 	/* go to local mode */
 	void ( *return_to_local )( gpib_board_t *board );
+	/* board does not support 7 bit eos comparisons */
+	unsigned no_7_bit_eos : 1;
 };
 
 typedef struct
@@ -205,7 +207,7 @@ struct gpib_board_struct
 	/* Watchdog timer to enable timeouts */
 	struct timer_list timer;
 	/* IO base address to use for non-pnp cards (set by core, driver should make local copy) */
-	unsigned long ibbase;
+	void *ibbase;
 	/* IRQ to use for non-pnp cards (set by core, driver should make local copy) */
 	unsigned int ibirq;
 	/* dma channel to use for non-pnp cards (set by core, driver should make local copy) */
@@ -300,6 +302,8 @@ typedef struct
 {
 	volatile short holding_mutex;
 	gpib_descriptor_t *descriptors[ GPIB_MAX_NUM_DESCRIPTORS ];
+	/* locked while descriptors are being allocated/deallocated */
+	struct semaphore descriptors_mutex;
 	unsigned got_module : 1;
 } gpib_file_private_t;
 
