@@ -23,6 +23,7 @@
 #include "gpibP.h"
 #include "plx9050.h"
 #include "amcc5920.h"
+#include "quancom_pci.h"
 #include <linux/config.h>
 #include <linux/interrupt.h>
 
@@ -53,7 +54,8 @@ extern gpib_interface_t ines_pci_interface;
 extern gpib_interface_t ines_pci_accel_interface;
 extern gpib_interface_t ines_pcmcia_interface;
 extern gpib_interface_t ines_pcmcia_accel_interface;
-
+extern gpib_interface_t ines_pcmcia_unaccel_interface;
+ 
 // interface functions
 ssize_t ines_read(gpib_board_t *board, uint8_t *buffer, size_t length, int *end, int *nbytes);
 ssize_t ines_write(gpib_board_t *board, uint8_t *buffer, size_t length, int send_eoi);
@@ -65,7 +67,7 @@ int ines_go_to_standby(gpib_board_t *board);
 void ines_request_system_control( gpib_board_t *board, int request_control );
 void ines_interface_clear(gpib_board_t *board, int assert);
 void ines_remote_enable(gpib_board_t *board, int enable);
-void ines_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits);
+int ines_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits);
 void ines_disable_eos(gpib_board_t *board);
 unsigned int ines_update_status( gpib_board_t *board, unsigned int clear_mask );
 void ines_primary_address(gpib_board_t *board, unsigned int address);
@@ -80,7 +82,8 @@ unsigned int ines_t1_delay( gpib_board_t *board, unsigned int nano_sec );
 void ines_return_to_local( gpib_board_t *board );
 
 // interrupt service routines
-irqreturn_t ines_interrupt(int irq, void *arg, struct pt_regs *registerp);
+irqreturn_t ines_pci_interrupt(int irq, void *arg, struct pt_regs *registerp);
+irqreturn_t ines_interrupt(gpib_board_t *board);
 
 // utility functions
 void ines_free_private(gpib_board_t *board);
@@ -91,11 +94,11 @@ void ines_set_xfer_counter( ines_private_t *priv, unsigned int count );
 /* inb/outb wrappers */
 static inline unsigned int ines_inb( ines_private_t *priv, unsigned int register_number )
 {
-	return inb( priv->nec7210_priv.iobase + register_number * priv->nec7210_priv.offset );
+	return inb((unsigned long)(priv->nec7210_priv.iobase) + register_number * priv->nec7210_priv.offset );
 }
 static inline void ines_outb( ines_private_t *priv, unsigned int value, unsigned int register_number )
 {
-	outb( value, priv->nec7210_priv.iobase + register_number * priv->nec7210_priv.offset );
+	outb( value, (unsigned long)(priv->nec7210_priv.iobase) + register_number * priv->nec7210_priv.offset );
 }
 
 // pcmcia init/cleanup
@@ -224,18 +227,6 @@ enum ines_auxd_bits
 	INES_T6_50us = 0x10,
 };
 
-/* quancom registers */
-enum quancom_regs
-{
-	QUANCOM_IRQ_CONTROL_STATUS_REG = 0xfc,
-};
-
-enum quancom_irq_control_status_bits
-{
-	QUANCOM_IRQ_ASSERTED_BIT = 0x1, /* readable (any write to the register clears the interrupt)*/
-	QUANCOM_IRQ_ENABLE_BIT = 0x4, /* writeable */
-};
-
 static const int ines_isa_iosize = 0x20;
 
 #endif	// _INES_GPIB_H
