@@ -28,6 +28,7 @@
 #include <linux/slab.h>
 #include <linux/string.h>
 #include <linux/timer.h>
+#include <linux/version.h>
 #include <linux/module.h>
 #include <asm/io.h>
 #include <asm/system.h>
@@ -41,8 +42,6 @@
 
 
 static int pc_debug = 1;
-static char *version =
-	"$Id: ines_cs.c,v 1.41 2005/06/05 19:20:51 fmhess Exp $";
 
 /* Parameters that can be set with 'insmod' */
 
@@ -211,11 +210,13 @@ static dev_link_t *gpib_attach(void)
 	dev_list = link;
 	client_reg.dev_info = &dev_info;
 	client_reg.Attributes = INFO_IO_CLIENT | INFO_CARD_SHARE;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13)    
 	client_reg.EventMask =
-	CS_EVENT_CARD_INSERTION | CS_EVENT_CARD_REMOVAL |
-	CS_EVENT_RESET_PHYSICAL | CS_EVENT_CARD_RESET |
-	CS_EVENT_PM_SUSPEND | CS_EVENT_PM_RESUME;
+		CS_EVENT_CARD_INSERTION | CS_EVENT_CARD_REMOVAL |
+		CS_EVENT_RESET_PHYSICAL | CS_EVENT_CARD_RESET |
+		CS_EVENT_PM_SUSPEND | CS_EVENT_PM_RESUME;
 	client_reg.event_handler = &gpib_event;
+#endif	
 	client_reg.Version = 0x0210;
 	client_reg.event_callback_args.client_data = link;
 	ret = pcmcia_register_client(&link->handle, &client_reg);
@@ -290,7 +291,7 @@ static void gpib_config(dev_link_t *link)
 	u_char buf[64];
 	win_req_t req;
 	memreq_t mem;
-	unsigned long virt;
+	void *virt;
 
 	dev = link->priv;
 
@@ -384,7 +385,7 @@ static void gpib_config(dev_link_t *link)
 			cs_error(link->handle, MapMemPage, i);
 			break;
 		}
-		virt = ( unsigned long ) ioremap( req.Base, req.Size );
+		virt = ioremap( req.Base, req.Size );
 		writeb( ( link->io.BasePort1 >> 2 ) & 0xff, virt + 0xf0 ); // IOWindow base
 		iounmap( ( void* ) virt );
 
@@ -527,8 +528,11 @@ static int gpib_event(event_t event, int priority,
 
 static struct pcmcia_driver ines_gpib_cs_driver =
 {
-	.attach = gpib_attach,
-	.detach = gpib_detach,
+	.attach = &gpib_attach,
+	.detach = &gpib_detach,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,13)
+	.event = &gpib_event,
+#endif
 	.owner = THIS_MODULE,
 	.drv = {
 		.name = "ines_gpib_cs",
@@ -538,16 +542,6 @@ static struct pcmcia_driver ines_gpib_cs_driver =
 
 int ines_pcmcia_init_module(void)
 {
-	servinfo_t serv;
-	if (pc_debug)
-		printk(KERN_INFO "%s\n", version);
-	pcmcia_get_card_services_info(&serv);
-	if (serv.Revision != CS_RELEASE_CODE)
-	{
-		printk(KERN_NOTICE "gpib: Card Services release "
-			"does not match!\n");
-		return -1;
-	}
 	pcmcia_register_driver(&ines_gpib_cs_driver);
 	return 0;
 }
@@ -671,7 +665,7 @@ int ines_common_pcmcia_attach( gpib_board_t *board )
 	ines_priv = board->private_data;
 	nec_priv = &ines_priv->nec7210_priv;
 
-	nec_priv->iobase = dev_list->io.BasePort1;
+	nec_priv->iobase = (void*)(unsigned long)dev_list->io.BasePort1;
 
 	nec7210_board_reset( nec_priv, board );
 
