@@ -20,14 +20,11 @@
 #include "ines.h"
 
 #include <linux/pci.h>
+#include <linux/pci_ids.h>
 #include <asm/io.h>
 #include <linux/module.h>
 #include <linux/init.h>
 
-#ifndef PCI_VENDOR_ID_QUANCOM
-#define PCI_VENDOR_ID_QUANCOM	0x8008
-#endif
-
 MODULE_LICENSE("GPL");
 
 int ines_pci_attach(gpib_board_t *board, gpib_board_config_t config);
@@ -46,7 +43,6 @@ enum ines_pci_device_ids
 {
 	PCI_DEVICE_ID_INES_GPIB_AMCC = 0x8507,
 	PCI_DEVICE_ID_INES_GPIB_QL5030 = 0x11,
-	PCI_DEVICE_ID_QUANCOM_GPIB = 0x3302
 };
 
 enum ines_pci_subdevice_ids
@@ -54,7 +50,7 @@ enum ines_pci_subdevice_ids
 	PCI_SUBDEVICE_ID_INES_GPIB = 0x1072
 };
 
-static struct pci_device_id ines_pci_table[] __devinitdata = 
+static struct pci_device_id ines_pci_table[] = 
 {
 	{PCI_VENDOR_ID_PLX, PCI_DEVICE_ID_PLX_9050, PCI_VENDOR_ID_PLX, PCI_SUBDEVICE_ID_INES_GPIB, 0, 0, 0},
 	{PCI_VENDOR_ID_AMCC, PCI_DEVICE_ID_INES_GPIB_AMCC, PCI_VENDOR_ID_AMCC, PCI_SUBDEVICE_ID_INES_GPIB, 0, 0, 0},
@@ -170,10 +166,10 @@ void ines_remote_enable(gpib_board_t *board, int enable)
 	ines_private_t *priv = board->private_data;
 	nec7210_remote_enable(board, &priv->nec7210_priv, enable);
 }
-void ines_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits)
+int ines_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits)
 {
 	ines_private_t *priv = board->private_data;
-	nec7210_enable_eos(board, &priv->nec7210_priv, eos_byte, compare_8_bits);
+	return nec7210_enable_eos(board, &priv->nec7210_priv, eos_byte, compare_8_bits);
 }
 void ines_disable_eos(gpib_board_t *board)
 {
@@ -388,8 +384,6 @@ void ines_online( ines_private_t *ines_priv, const gpib_board_t *board, int use_
 	write_byte( nec_priv, ICR | 0, AUXMR );
 
 	write_byte( nec_priv, INES_AUX_XMODE, AUXMR );
-	write_byte( nec_priv, INES_AUX_CLR_IN_FIFO, AUXMR );
-	write_byte( nec_priv, INES_AUX_CLR_OUT_FIFO, AUXMR );
 	write_byte( nec_priv, INES_RFD_HLD_IMMEDIATE, AUXMR );
 	set_bit( RFD_HOLDOFF_BN, &nec_priv->state );
 	write_byte( nec_priv, INES_AUXD | 0, AUXMR );
@@ -403,8 +397,6 @@ void ines_online( ines_private_t *ines_priv, const gpib_board_t *board, int use_
 		ines_outb( ines_priv, IFC_ACTIVE_BIT | ATN_ACTIVE_BIT | FIFO_ERROR_BIT | XFER_COUNT_BIT, IMR3 );
 		ines_outb( ines_priv, IN_FIFO_WATERMARK_BIT | IN_FIFO_FULL_BIT | OUT_FIFO_WATERMARK_BIT |
 			OUT_FIFO_EMPTY_BIT, IMR4 );
-		nec7210_set_reg_bits( nec_priv, ADMR, IN_FIFO_ENABLE_BIT | OUT_FIFO_ENABLE_BIT,
-			IN_FIFO_ENABLE_BIT | OUT_FIFO_ENABLE_BIT );
 	}else
 	{
 		nec7210_set_reg_bits( nec_priv, ADMR, IN_FIFO_ENABLE_BIT | OUT_FIFO_ENABLE_BIT, 0 );
@@ -471,7 +463,7 @@ int ines_common_pci_attach( gpib_board_t *board )
 
 	if(pci_request_regions(ines_priv->pci_device, "ines-gpib"))
 		return -1;
-	nec_priv->iobase = pci_resource_start(ines_priv->pci_device, found_id.gpib_region);
+	nec_priv->iobase = (void*)(pci_resource_start(ines_priv->pci_device, found_id.gpib_region));
 
 	ines_priv->pci_chip_type = found_id.pci_chip_type;
 	nec_priv->offset = found_id.io_offset;
@@ -505,7 +497,7 @@ int ines_common_pci_attach( gpib_board_t *board )
 	}
 #endif	
 	isr_flags |= SA_SHIRQ;
-	if(request_irq(ines_priv->pci_device->irq, ines_interrupt, isr_flags, "pci-gpib", board))
+	if(request_irq(ines_priv->pci_device->irq, ines_pci_interrupt, isr_flags, "pci-gpib", board))
 	{
 		printk("gpib: can't request IRQ %d\n",ines_priv->pci_device->irq);
 		return -1;
@@ -534,7 +526,7 @@ int ines_common_pci_attach( gpib_board_t *board )
 			}
 			break;
 		case PCI_CHIP_QUANCOM:
-			outb( QUANCOM_IRQ_ENABLE_BIT, nec_priv->iobase + QUANCOM_IRQ_CONTROL_STATUS_REG );
+			outb( QUANCOM_IRQ_ENABLE_BIT, (unsigned long)(nec_priv->iobase) + QUANCOM_IRQ_CONTROL_STATUS_REG );
 			break;
 		case PCI_CHIP_QUICKLOGIC5030:
 			break;
@@ -589,15 +581,15 @@ int ines_isa_attach( gpib_board_t *board, gpib_board_config_t config )
 	nec_priv = &ines_priv->nec7210_priv;
 
 	
-	if(request_region(board->ibbase, ines_isa_iosize, "ines_gpib") == 0)
+	if(request_region((unsigned long)(board->ibbase), ines_isa_iosize, "ines_gpib") == 0)
 	{
-		printk("ines_gpib: ioports at 0x%lx already in use\n", board->ibbase);
+		printk("ines_gpib: ioports at 0x%p already in use\n", board->ibbase);
 		return -1;
 	}
 	nec_priv->iobase = board->ibbase;
 	nec_priv->offset = 1;
 	nec7210_board_reset(nec_priv, board);
-	if(request_irq(board->ibirq, ines_interrupt, isr_flags, "ines_gpib", board))
+	if(request_irq(board->ibirq, ines_pci_interrupt, isr_flags, "ines_gpib", board))
 	{
 		printk("ines_gpib: failed to allocate IRQ %d\n", board->ibirq);
 		return -1;
@@ -626,7 +618,7 @@ void ines_pci_detach(gpib_board_t *board)
 				break;
 			case PCI_CHIP_QUANCOM:
 				if( nec_priv->iobase )
-					outb( 0, nec_priv->iobase + QUANCOM_IRQ_CONTROL_STATUS_REG );
+					outb( 0, (unsigned long)(nec_priv->iobase) + QUANCOM_IRQ_CONTROL_STATUS_REG );
 				break;
 			default:
 				break;
@@ -659,7 +651,7 @@ void ines_isa_detach(gpib_board_t *board)
 		if(nec_priv->iobase)
 		{
 			nec7210_board_reset( nec_priv, board );
-			release_region(nec_priv->iobase, ines_isa_iosize);
+			release_region((unsigned long)(nec_priv->iobase), ines_isa_iosize);
 		}
 	}
 	ines_free_private(board);
