@@ -85,6 +85,7 @@ static int init_gpib_file_private( gpib_file_private_t *priv )
 	}
 	init_gpib_descriptor( priv->descriptors[ 0 ] );
 	priv->descriptors[ 0 ]->is_board = 1;
+	init_MUTEX(&priv->descriptors_mutex);
 	return 0;
 }
 
@@ -264,6 +265,12 @@ int ibioctl(struct inode *inode, struct file *filep, unsigned int cmd, unsigned
 		case IBEVENT:
 			return event_ioctl( board, arg );
 			break;
+		case IBCLOSEDEV:
+			return close_dev_ioctl( filep, board, arg );
+			break;
+		case IBOPENDEV:
+			return open_dev_ioctl( filep, board, arg );
+			break;
 		case IBSPOLL_BYTES:
 			return status_bytes_ioctl( board, arg );
 			break;
@@ -296,9 +303,6 @@ int ibioctl(struct inode *inode, struct file *filep, unsigned int cmd, unsigned
 		case IBCAC:
 			return take_control_ioctl( board, arg );
 			break;
-		case IBCLOSEDEV:
-			return close_dev_ioctl( filep, board, arg );
-			break;
 		case IBCMD:
 			return command_ioctl( file_priv, board, arg );
 			break;
@@ -308,9 +312,6 @@ int ibioctl(struct inode *inode, struct file *filep, unsigned int cmd, unsigned
 		case IBGTS:
 			return ibgts( board );
 			break;
-		case IBOPENDEV:
-			return open_dev_ioctl( filep, board, arg );
-			break;
 		case IBPPC:
 			return ppc_ioctl( board, arg );
 			break;
@@ -431,8 +432,7 @@ static int read_ioctl( gpib_file_private_t *file_priv, gpib_board_t *board,
 	if( desc == NULL ) return -EINVAL;
 
 	/* Check write access to buffer */
-	retval = verify_area(VERIFY_WRITE, read_cmd.buffer, read_cmd.count);
-	if (retval)
+	if(!access_ok(VERIFY_WRITE, read_cmd.buffer, read_cmd.count))
 		return -EFAULT;
 
 	desc->io_in_progress = 1;
@@ -479,8 +479,7 @@ static int command_ioctl( gpib_file_private_t *file_priv,
 	if( desc == NULL ) return -EINVAL;
 
 	/* Check read access to buffer */
-	retval = verify_area(VERIFY_READ, cmd.buffer, cmd.count);
-	if (retval)
+	if(!access_ok(VERIFY_READ, cmd.buffer, cmd.count))
 		return -EFAULT;
 
 	/* Write buffer loads till we empty the user supplied buffer */
@@ -534,8 +533,7 @@ static int write_ioctl( gpib_file_private_t *file_priv, gpib_board_t *board,
 	if( desc == NULL ) return -EINVAL;
 
 	/* Check read access to buffer */
-	retval = verify_area(VERIFY_READ, write_cmd.buffer, write_cmd.count);
-	if (retval)
+	if(!access_ok(VERIFY_READ, write_cmd.buffer, write_cmd.count))
 		return -EFAULT;
 
 	desc->io_in_progress = 1;
@@ -615,7 +613,7 @@ static int increment_open_device_count( struct list_head *head, unsigned int pad
 	}
 
 	/* otherwise we need to allocate a new gpib_status_queue_t */
-	device = kmalloc( sizeof( gpib_status_queue_t ), GFP_KERNEL );
+	device = kmalloc( sizeof( gpib_status_queue_t ), GFP_ATOMIC );
 	if( device == NULL )
 		return -ENOMEM;
 	init_gpib_status_queue( device );
@@ -704,18 +702,26 @@ static int open_dev_ioctl( struct file *filep, gpib_board_t *board, unsigned lon
 	if (retval)
 		return -EFAULT;
 
+	if(down_interruptible(&file_priv->descriptors_mutex))
+	{
+		return -ERESTARTSYS;
+	}
 	for( i = 0; i < GPIB_MAX_NUM_DESCRIPTORS; i++ )
 		if( file_priv->descriptors[ i ] == NULL ) break;
 	if( i == GPIB_MAX_NUM_DESCRIPTORS )
 		return -ERANGE;
 	file_priv->descriptors[ i ] = kmalloc( sizeof( gpib_descriptor_t ), GFP_KERNEL );
 	if( file_priv->descriptors[ i ] == NULL )
+	{
+		up(&file_priv->descriptors_mutex);
 		return -ENOMEM;
+	}
 	init_gpib_descriptor( file_priv->descriptors[ i ] );
 
 	file_priv->descriptors[ i ]->pad = open_dev_cmd.pad;
 	file_priv->descriptors[ i ]->sad = open_dev_cmd.sad;
 	file_priv->descriptors[ i ]->is_board = open_dev_cmd.is_board;
+	up(&file_priv->descriptors_mutex);
 
 	retval = increment_open_device_count( &board->device_list, open_dev_cmd.pad, open_dev_cmd.sad );
 	if( retval < 0 )
@@ -1001,7 +1007,7 @@ static int iobase_ioctl( gpib_board_t *board, unsigned long arg )
 	if( retval )
 		return -EFAULT;
 
-	board->ibbase = base_addr;
+	board->ibbase = (void*)(base_addr);
 
 	return 0;
 }
@@ -1194,7 +1200,7 @@ static int board_info_ioctl( const gpib_board_t *board, unsigned long arg)
 		info.autopolling = 0;
 	info.t1_delay = board->t1_nano_sec;
 	info.ist = board->ist;
-	
+	info.no_7_bit_eos = board->interface->no_7_bit_eos;
 	retval = copy_to_user( ( void * ) arg, &info, sizeof( info ) );
 	if( retval )
 		return -EFAULT;
