@@ -67,7 +67,7 @@ void init_gpib_descriptor( gpib_descriptor_t *desc )
 void gpib_register_driver(gpib_interface_t *interface, struct module *provider_module)
 {
 	struct gpib_interface_list_struct *entry;
-	
+
 	entry = kmalloc(sizeof(struct gpib_interface_list_struct), GFP_KERNEL);
 	if(entry == NULL)
 	{
@@ -199,10 +199,11 @@ void init_gpib_status_queue( gpib_status_queue_t *device )
 	device->dropped_byte = 0;
 }
 
-static struct class_simple *gpib_class;
+static struct class *gpib_class;
 
 static int __init gpib_common_init_module( void )
 {
+	int i;
 	printk("Linux-GPIB %s Driver -- Kernel Release %s\n", VERSION, UTS_RELEASE);
 	init_board_array(board_array, GPIB_MAX_NUM_BOARDS);
 	if(register_chrdev(IBMAJOR, "gpib", &ib_fops))
@@ -210,17 +211,16 @@ static int __init gpib_common_init_module( void )
 		printk( "gpib: can't get major %d\n", IBMAJOR );
 		return -EIO;
 	}
-	gpib_class = class_simple_create(THIS_MODULE, "gpib_common");
+	gpib_class = class_create(THIS_MODULE, "gpib_common");
 	if(IS_ERR(gpib_class))
 	{
 		printk("gpib: failed to create gpib class\n");
 		unregister_chrdev(IBMAJOR, "gpib");
 		return PTR_ERR(gpib_class);
 	}
-	int i;
 	for(i = 0; i < GPIB_MAX_NUM_BOARDS; ++i)
 	{
-		class_simple_device_add(gpib_class, MKDEV(IBMAJOR, i), NULL, "gpib%i", i);
+		class_device_create(gpib_class, MKDEV(IBMAJOR, i), NULL, "gpib%i", i);
 	}
 	return 0;
 }
@@ -228,16 +228,17 @@ static int __init gpib_common_init_module( void )
 static void __exit gpib_common_exit_module( void )
 {
 	int i;
+	int retval;
 	for(i = 0; i < GPIB_MAX_NUM_BOARDS; ++i)
 	{
-		class_simple_device_remove(MKDEV(IBMAJOR, i));
+		class_device_destroy(gpib_class, MKDEV(IBMAJOR, i));
 	}
-	class_simple_destroy(gpib_class);
-	int retval = unregister_chrdev(IBMAJOR, "gpib");
-	if(retval) 
+	class_destroy(gpib_class);
+	retval = unregister_chrdev(IBMAJOR, "gpib");
+	if(retval)
 	{
 		printk("gpib: unregister_chrdev() returned error %i\n", retval);
-	}else 
+	}else
 	{
 		printk("gpib: succesfully removed \n");
 	}
