@@ -30,6 +30,7 @@
 #include <linux/slab.h>
 #include <linux/string.h>
 #include <linux/timer.h>
+#include <linux/version.h>
 #include <linux/ioport.h>
 #include <asm/io.h>
 #include <asm/system.h>
@@ -217,12 +218,14 @@ static dev_link_t *ni_gpib_attach(void)
     dev_list = link;
     client_reg.dev_info = &dev_info;
     client_reg.Attributes = INFO_IO_CLIENT | INFO_CARD_SHARE;
-    client_reg.EventMask =
-	CS_EVENT_CARD_INSERTION | CS_EVENT_CARD_REMOVAL |
-	CS_EVENT_RESET_PHYSICAL | CS_EVENT_CARD_RESET |
-	CS_EVENT_PM_SUSPEND | CS_EVENT_PM_RESUME;
-    client_reg.event_handler = &ni_gpib_event;
-    client_reg.Version = 0x0210;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13)    
+	client_reg.EventMask =
+		CS_EVENT_CARD_INSERTION | CS_EVENT_CARD_REMOVAL |
+		CS_EVENT_RESET_PHYSICAL | CS_EVENT_CARD_RESET |
+		CS_EVENT_PM_SUSPEND | CS_EVENT_PM_RESUME;
+	client_reg.event_handler = &ni_gpib_event;
+#endif    
+	client_reg.Version = 0x0210;
     client_reg.event_callback_args.client_data = link;
     ret = pcmcia_register_client(&link->handle, &client_reg);
     if (ret != CS_SUCCESS) {
@@ -661,8 +664,11 @@ static int ni_gpib_event(event_t event, int priority,
 /*====================================================================*/
 static struct pcmcia_driver ni_gpib_cs_driver =
 {
-	.attach = ni_gpib_attach,
-	.detach = ni_gpib_detach,
+	.attach = &ni_gpib_attach,
+	.detach = &ni_gpib_detach,
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,13)
+	.event = &ni_gpib_event,
+#endif	
 	.owner = THIS_MODULE,
 	.drv = {
 		.name = "ni_gpib_cs",
@@ -671,15 +677,6 @@ static struct pcmcia_driver ni_gpib_cs_driver =
 
 int __init init_ni_gpib_cs(void)
 {
-	servinfo_t serv;
-	
-	DEBUG(0, "%s\n", version);
-	pcmcia_get_card_services_info(&serv);
-	if (serv.Revision != CS_RELEASE_CODE) {
-		printk( "ni_gpib_cs: Card Services release "
-			"does not match!  Revision = %i, CS_RELEASE_CODE = %i\n", serv.Revision, CS_RELEASE_CODE );
-		return -EINVAL;
-	}
 	pcmcia_register_driver(&ni_gpib_cs_driver);
 	return 0;
 }
@@ -695,7 +692,7 @@ void __exit exit_ni_gpib_cs(void)
 	}
 }
 
-int ni_pcmcia_attach(gpib_board_t *board);
+int ni_pcmcia_attach(gpib_board_t *board, gpib_board_config_t config);
 void ni_pcmcia_detach(gpib_board_t *board);
 
 gpib_interface_t ni_pcmcia_interface =
@@ -754,7 +751,7 @@ gpib_interface_t ni_pcmcia_accel_interface =
 	return_to_local: tnt4882_return_to_local,
 };
 
-int ni_pcmcia_attach(gpib_board_t *board)
+int ni_pcmcia_attach(gpib_board_t *board, gpib_board_config_t config)
 {
 	tnt4882_private_t *tnt_priv;
 	nec7210_private_t *nec_priv;
@@ -782,7 +779,7 @@ int ni_pcmcia_attach(gpib_board_t *board)
 	nec_priv->offset = atgpib_reg_offset;
 
 	GPIB_DPRINTK( "ioport1 window attributes: 0x%x\n", dev_list->io.Attributes1 );
-	nec_priv->iobase = dev_list->io.BasePort1;
+	nec_priv->iobase = (void*)(unsigned long)dev_list->io.BasePort1;
 
 	// get irq
 	if( request_irq( dev_list->irq.AssignedIRQ, tnt4882_interrupt, isr_flags, "tnt4882", board))
