@@ -103,10 +103,10 @@ void tnt4882_remote_enable(gpib_board_t *board, int enable)
 	tnt4882_private_t *priv = board->private_data;
 	nec7210_remote_enable(board, &priv->nec7210_priv, enable);
 }
-void tnt4882_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits)
+int tnt4882_enable_eos(gpib_board_t *board, uint8_t eos_byte, int compare_8_bits)
 {
 	tnt4882_private_t *priv = board->private_data;
-	nec7210_enable_eos(board, &priv->nec7210_priv, eos_byte, compare_8_bits);
+	return nec7210_enable_eos(board, &priv->nec7210_priv, eos_byte, compare_8_bits);
 }
 void tnt4882_disable_eos(gpib_board_t *board)
 {
@@ -130,8 +130,20 @@ void tnt4882_secondary_address(gpib_board_t *board, unsigned int address, int en
 }
 int tnt4882_parallel_poll(gpib_board_t *board, uint8_t *result)
 {
-	tnt4882_private_t *priv = board->private_data;
-	return nec7210_parallel_poll(board, &priv->nec7210_priv, result);
+	tnt4882_private_t *tnt_priv = board->private_data;
+	if(tnt_priv->nec7210_priv.type != NEC7210)
+	{
+		tnt_priv->auxg_bits |= RPP2_BIT;
+		write_byte(&tnt_priv->nec7210_priv, tnt_priv->auxg_bits, AUXMR);
+		udelay(2);	//FIXME use parallel poll timeout
+		*result = read_byte(&tnt_priv->nec7210_priv, CPTR);
+		tnt_priv->auxg_bits &= ~RPP2_BIT;
+		write_byte(&tnt_priv->nec7210_priv, tnt_priv->auxg_bits, AUXMR);
+		return 0;
+	}else
+	{
+		return nec7210_parallel_poll(board, &tnt_priv->nec7210_priv, result);
+	}
 }
 void tnt4882_parallel_poll_configure(gpib_board_t *board, uint8_t config )
 {
@@ -457,7 +469,8 @@ void tnt4882_init( tnt4882_private_t *tnt_priv, const gpib_board_t *board )
 	write_byte( &tnt_priv->nec7210_priv, AUX_HLDI, AUXMR );
 	set_bit( RFD_HOLDOFF_BN, &nec_priv->state );
 
-	write_byte( &tnt_priv->nec7210_priv, AUXRG | NTNL_BIT, AUXMR );
+	tnt_priv->auxg_bits = AUXRG | NTNL_BIT;
+	write_byte( &tnt_priv->nec7210_priv, tnt_priv->auxg_bits, AUXMR );
 
 	nec7210_board_online( nec_priv, board );
 	// enable interface clear interrupt for event queue
@@ -520,7 +533,7 @@ int ni_pci_attach(gpib_board_t *board, gpib_board_config_t config)
 		return -1;
 	}
 
-	nec_priv->iobase = mite_iobase(tnt_priv->mite);
+	nec_priv->iobase = tnt_priv->mite->daq_io_addr;
 
 	// get irq
 	if(request_irq(mite_irq(tnt_priv->mite), tnt4882_interrupt, isr_flags, "ni-pci-gpib", board))
@@ -593,7 +606,7 @@ int ni_isa_attach_common( gpib_board_t *board, enum nec7210_chipset chipset )
 	tnt4882_private_t *tnt_priv;
 	nec7210_private_t *nec_priv;
 	int isr_flags = 0;
-	unsigned long iobase;
+	void *iobase;
 
 	board->status = 0;
 
@@ -619,13 +632,13 @@ int ni_isa_attach_common( gpib_board_t *board, enum nec7210_chipset chipset )
 		retval = ni_isapnp_find( &dev );
 		if( retval < 0 ) return retval;
 		tnt_priv->pnp_dev = dev;
-		iobase = pnp_port_start(dev, 0);
+		iobase = (void*)(pnp_port_start(dev, 0));
 		board->ibirq = pnp_irq(dev, 0);
 	}else
 		iobase = board->ibbase;
 
 	// allocate ioports
-	if( request_region( iobase, atgpib_iosize, "atgpib") == NULL )
+	if(request_region((unsigned long)(iobase), atgpib_iosize, "atgpib") == NULL)
 	{
 		printk("tnt4882: failed to allocate ioports\n");
 		return -1;
@@ -678,7 +691,7 @@ void ni_isa_detach(gpib_board_t *board)
 		}
 		if( nec_priv->iobase )
 		{
-			release_region(nec_priv->iobase, atgpib_iosize);
+			release_region((unsigned long)(nec_priv->iobase), atgpib_iosize);
 		}
 		if(tnt_priv->pnp_dev)
 		{			
@@ -688,7 +701,7 @@ void ni_isa_detach(gpib_board_t *board)
 	tnt4882_free_private(board);
 }
 
-static struct pci_device_id tnt4882_pci_table[] __devinitdata = 
+static const struct pci_device_id tnt4882_pci_table[] = 
 {
 	{PCI_DEVICE(PCI_VENDOR_ID_NATINST, PCI_DEVICE_ID_NI_GPIB)},
 	{PCI_DEVICE(PCI_VENDOR_ID_NATINST, PCI_DEVICE_ID_NI_GPIB_PLUS)},
