@@ -34,7 +34,6 @@ computer, on the same GPIB bus, and one of which is the system controller.
 
 struct program_options
 {
-	int daemonize_index;
 	int num_loops;
 	int master;
 	int pad;
@@ -47,25 +46,31 @@ struct program_options
 	fprintf( stderr, "FAILED: %s line %i, ibsta 0x%x, iberr %i, ibcntl %li\n", \
 		__FILE__, __LINE__, ThreadIbsta(), ThreadIberr(), ThreadIbcntl() ); \
 
-static int send_sync_message(int ud, const char *message)
+static int sync_message(const struct program_options *options, const char *message)
 {
-	if(ibwrt(ud, message, strlen(message)) & ERR)
+	char buffer[1024] = {0};
+	if(options->verbosity)
 	{
-		fprintf(stderr, "failed to send sync message: %s\n", message);
+		fprintf(stderr, "syncing: master=%i, message=%s\n", options->master, message);
+	}
+	if(options->master)
+	{
+		fprintf(stdout, "%s\n", message);
+		fflush(stdout);
+	}
+	fgets(buffer, sizeof(buffer), stdin);
+	if(strncmp(message, buffer, strlen(message)))
+	{
+		fprintf(stderr, "received unexpected sync message: %s\n", buffer);
+		fprintf(stderr, "expected: %s\n", message);
 		PRINT_FAILED();
 		return -1;
 	}
-	return 0;
-}
-
-static int receive_sync_message(int ud)
-{
-	char buffer[1024];
-
-	if(ibrd(ud, buffer, sizeof(buffer)) & ERR)
+	if(options->master == 0)
 	{
-		PRINT_FAILED();
-		return -1;
+		// echo back
+		fprintf(stdout, "%s\n", message);
+		fflush(stdout);
 	}
 	return 0;
 }
@@ -169,6 +174,18 @@ static int find_board(int *board, const struct program_options *options)
 	return 0;
 }
 
+Addr4882_t slaveAddress(const struct program_options *options)
+{
+	Addr4882_t address;
+	int sad;
+	if(options->sad >= 0)
+		sad = MSA(options->sad);
+	else
+		sad = 0;
+	address = MakeAddr(options->pad, sad);
+	return address;
+}
+
 static int open_slave_device_descriptor(int board, const struct program_options *options,
 	int timeout, int eot, int eos )
 {
@@ -194,7 +211,7 @@ static int master_read_write_test(int board, const struct program_options *optio
 {
 	int ud;
 	int status;
-	char buffer[ 1000 ];
+	char buffer[1000];
 	int i;
 
 	fprintf( stderr, "%s...", __FUNCTION__ );
@@ -209,21 +226,25 @@ static int master_read_write_test(int board, const struct program_options *optio
 		if( ( status & ERR ) || !( status & CMPL ) )
 		{
 			PRINT_FAILED();
+			fprintf(stderr, "\tloop %i\n", i);
 			ibonl( ud, 0 );
 			return -1;
 		}
 		memset( buffer, 0, sizeof( buffer ) );
-		status = ibrd( ud, buffer, sizeof( buffer ) );
+		status = ibrd(ud, buffer, sizeof(buffer) - 1);
 		if( ( status & ERR ) || !( status & CMPL ) || !( status & END ) )
 		{
 			PRINT_FAILED();
+			fprintf( stderr, "received bytes:\"%s\"\n", buffer );
+			fprintf(stderr, "loop %i\n", i);
 			ibonl( ud, 0 );
 			return -1;
 		}
 		if(strcmp(buffer, read_write_string2))
 		{
 			PRINT_FAILED();
-			fprintf( stderr, "received bytes:%s\n", buffer );
+			fprintf( stderr, "received bytes:\"%s\"\n", buffer );
+			fprintf(stderr, "\tloop %i\n", i);
 			ibonl( ud, 0 );
 			return -1;
 		}
@@ -252,6 +273,7 @@ static int slave_read_write_test(int board, const struct program_options *option
 		if(status & ERR)
 		{
 			PRINT_FAILED();
+			fprintf(stderr, "loop %i\n", i);
 			return -1;
 		}
 		if(strcmp(buffer, read_write_string1))
@@ -259,12 +281,14 @@ static int slave_read_write_test(int board, const struct program_options *option
 			PRINT_FAILED();
 			fprintf( stderr, "got bad data from ibrd\n" );
 			fprintf( stderr, "received %i bytes:%s\n", ThreadIbcnt(), buffer );
+			fprintf(stderr, "loop %i\n", i);
 			return -1;
 		}
 		status = ibwrt(board, read_write_string2, strlen(read_write_string2) + 1);
 		if( status & ERR )
 		{
 			PRINT_FAILED();
+			fprintf(stderr, "loop %i\n", i);
 			return -1;
 		}
 	}
@@ -272,14 +296,6 @@ static int slave_read_write_test(int board, const struct program_options *option
 	return 0;
 }
 
-static int read_write_test(int board, const struct program_options *options)
-{
-	if(options->master)
-		return master_read_write_test(board, options);
-	else
-		return slave_read_write_test(board, options);
-};
-
 static int master_async_read_write_test(int board, const struct program_options *options)
 {
 	int ud;
@@ -303,7 +319,7 @@ static int master_async_read_write_test(int board, const struct program_options
 		if((status & (ERR | TIMO)) || !(status & CMPL) )
 		{
 			PRINT_FAILED();
-			fprintf( stderr, "write status 0x%x, error %i\n", ThreadIbsta(),
+			fprintf( stderr, "loop %i, write status 0x%x, error %i\n", i, ThreadIbsta(),
 				ThreadIberr() );
 			ibonl( ud, 0 );
 			return -1;
@@ -340,14 +356,14 @@ static int slave_async_read_write_test(int board, const struct program_options *
 		if((status & (ERR | TIMO)) || !(status & CMPL))
 		{
 			PRINT_FAILED();
-			fprintf( stderr, "write status 0x%x, error %i\n", ThreadIbsta(),
+			fprintf( stderr, "loop %i, read status 0x%x, error %i\n", i, ThreadIbsta(),
 				ThreadIberr() );
 			return -1;
 		}
 		if(strcmp(buffer, read_write_string1))
 		{
 			PRINT_FAILED();
-			fprintf( stderr, "got bad data from ibrd\n" );
+			fprintf( stderr, "loop %i got bad data from ibrd\n", i);
 			fprintf( stderr, "received %i bytes:%s\n", ThreadIbcnt(), buffer );
 			return -1;
 		}
@@ -356,14 +372,6 @@ static int slave_async_read_write_test(int board, const struct program_options *
 	return 0;
 }
 
-static int async_read_write_test(int board, const struct program_options *options)
-{
-	if(options->master)
-		return master_async_read_write_test(board, options);
-	else
-		return slave_async_read_write_test(board, options);
-};
-
 const int status_byte = 0x43;
 static int master_serial_poll_test(int board, const struct program_options *options)
 {
@@ -391,7 +399,7 @@ static int master_serial_poll_test(int board, const struct program_options *opti
 		ibonl( ud, 0 );
 		return -1;
 	}
-	if(send_sync_message(ud, "request service"))
+	if(sync_message(options, "request service"))
 	{
 		ibonl( ud, 0 );
 		return -1;
@@ -432,8 +440,9 @@ static int slave_serial_poll_test(int board, const struct program_options *optio
 {
 	fprintf( stderr, "%s...", __FUNCTION__ );
 
-	if(receive_sync_message(board))
+	if(sync_message(options, "request service"))
 	{
+		PRINT_FAILED();
 		return -1;
 	}
 	ibrsv(board, status_byte);
@@ -446,14 +455,6 @@ static int slave_serial_poll_test(int board, const struct program_options *optio
 	return 0;
 }
 
-static int serial_poll_test(int board, const struct program_options *options)
-{
-	if(options->master)
-		return master_serial_poll_test(board, options);
-	else
-		return slave_serial_poll_test(board, options);
-};
-
 static int master_parallel_poll_test(int board, const struct program_options *options)
 {
 	int ud;
@@ -464,7 +465,12 @@ static int master_parallel_poll_test(int board, const struct program_options *op
 	ud = open_slave_device_descriptor(board, options, T3s, 1, 0 );
 	if( ud < 0 )
 		return -1;
-	line = 2; sense = 1;
+	if(sync_message(options, "ist is 1"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	line = 4; sense = 1;
 	ibppc(ud, PPE_byte(line, sense));
 	if(ibsta & ERR)
 	{
@@ -483,6 +489,28 @@ static int master_parallel_poll_test(int board, const struct program_options *op
 		fprintf( stderr, "parallel poll result: 0x%x\n", (unsigned int)result );
 		return -1;
 	}
+	if(sync_message(options, "set ist to 0"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	if(sync_message(options, "ist is 0"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	ibrpp( board, &result );
+	if( ThreadIbsta() & ERR )
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if((result & (1 << (line - 1))))
+	{
+		PRINT_FAILED();
+		fprintf( stderr, "parallel poll result: 0x%x\n", (unsigned int)result );
+		return -1;
+	}
 	ibonl( ud, 0 );
 	if( ThreadIbsta() & ERR )
 	{
@@ -497,18 +525,37 @@ static int slave_parallel_poll_test(int board, const struct program_options *opt
 {
 	fprintf( stderr, "%s...", __FUNCTION__ );
 
+	ibist(board, 1);
+	if( ThreadIbsta() & ERR )
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "ist is 1"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "set ist to 0"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	ibist(board, 0);
+	if( ThreadIbsta() & ERR )
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "ist is 0"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
 	fprintf( stderr, "OK\n" );
 	return 0;
 }
 
-static int parallel_poll_test(int board, const struct program_options *options)
-{
-	if(options->master)
-		return master_parallel_poll_test(board, options);
-	else
-		return slave_parallel_poll_test(board, options);
-};
-
 static int do_master_eos_pass(int board, const struct program_options *options,
 	int eosmode, const char *test_message, const char *first_read_result,
 	const char *second_read_result)
@@ -516,18 +563,20 @@ static int do_master_eos_pass(int board, const struct program_options *options,
 	int ud;
 	char buffer[1024];
 
-	ud = open_slave_device_descriptor(board, options, T3s, 0, eosmode );
+	ud = open_slave_device_descriptor(board, options, T3s, 0, eosmode);
 	if( ud < 0 )
 		return -1;
 	ibrd(ud, buffer, sizeof(buffer) - 1);
+	buffer[ThreadIbcntl()] = '\0';
 	if( ThreadIbsta() & ERR )
 	{
 		PRINT_FAILED();
 		fprintf( stderr, "ibrd status 0x%x, error %i, count %li\n", ThreadIbsta(),
 			ThreadIberr(), ThreadIbcntl());
+		fprintf(stderr, "first read got: '%s'\n"
+			"expected: '%s'\n", buffer, first_read_result);
 		return -1;
 	}
-	buffer[ThreadIbcntl()] = '\0';
 	if(strcmp(buffer, first_read_result))
 	{
 		PRINT_FAILED();
@@ -566,9 +615,10 @@ static int do_slave_eos_pass(int board, const struct program_options *options,
 	const char *second_read_result)
 {
 	ibwrt(board, test_message, strlen(test_message));
-	if( ThreadIbsta() & ERR )
+	if(ThreadIbsta() & ERR)
 	{
 		PRINT_FAILED();
+		fprintf(stderr, "%s: test_message=%s\n", __FUNCTION__, test_message);
 		return -1;
 	}
 	return 0;
@@ -577,12 +627,27 @@ static int do_slave_eos_pass(int board, const struct program_options *options,
 static int master_eos_test(int board, const struct program_options *options)
 {
 	int retval;
+	int seven_bit_eos;
 	fprintf( stderr, "%s...", __FUNCTION__ );
 
-	retval = do_master_eos_pass(board, options, 'x' | REOS, "adfis\xf8gibblex",
-		"adfis\xf8", "gibblex");
-	if(retval < 0) return retval;
-
+	//check if board supports 7 bit eos compares
+	if(ibask(board, Iba7BitEOS, &seven_bit_eos) & ERR)
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(seven_bit_eos == 0)
+	{
+		fprintf(stderr, "board does not support 7 bit eos comparisons, skipping 7 bit eos test.\n");
+		retval = do_master_eos_pass(board, options, 0, "adfis\xf8gibblex",
+			"adfis\xf8gibblex", NULL);
+		if(retval < 0) return retval;
+	}else
+	{
+		retval = do_master_eos_pass(board, options, 'x' | REOS, "adfis\xf8gibblex",
+			"adfis\xf8", "gibblex");
+		if(retval < 0) return retval;
+	}
 	retval = do_master_eos_pass(board, options, 'x' | REOS | BIN, "adfis\xf8gibblex",
 		"adfis\xf8gibblex", NULL);
 	if(retval < 0) return retval;
@@ -608,68 +673,167 @@ static int slave_eos_test(int board, const struct program_options *options)
 	return 0;
 }
 
-static int eos_test(int board, const struct program_options *options)
+static int master_remote_and_lockout_test(int board, const struct program_options *options)
 {
-	if(options->master)
-		return master_eos_test(board, options);
-	else
-		return slave_eos_test(board, options);
-};
+	Addr4882_t addressList[] = {slaveAddress(options), NOADDR};
+	int ud;
+	
+	fprintf( stderr, "%s...", __FUNCTION__ );
 
-static void daemonize(void)
-{
-	pid_t my_pid;
+	ud = open_slave_device_descriptor(board, options, T3s, 1, 0);
+	if( ud < 0 )
+		return -1;
 
-	fprintf(stderr, "Attempting to daemonize.\n");
-
-	my_pid = fork();
-	if(my_pid)
+	EnableLocal(board, addressList);
+	if(sync_message(options, "set local mode"))
 	{
-		exit(0);
-	}else
-	{
-		my_pid = setsid();
-		if(my_pid < 0)
-		{
-			fprintf(stderr, "setsid() failed\n");
-			exit(1);
-		}
-		my_pid = fork();
-		if(my_pid)
-		{
-			exit(0);
-		}else
-		{
-			umask(0);
-			if(freopen("/dev/null", "r", stdin) == NULL)
-			{
-				fprintf(stderr, "failed to reopen stdin\n");
-				exit(1);
-			}
-			if(freopen("libgpib_test_daemon_output", "w", stdout) == NULL)
-			{
-				fprintf(stderr, "failed to reopen stdout\n");
-				exit(1);
-			}
-			if(freopen("libgpib_test_daemon_output", "w", stderr) == NULL)
-			{
-				fprintf(stderr, "failed to reopen stderr\n");
-				exit(1);
-			}
-			if(chdir("/"))
-			{
-				fprintf(stderr, "failed to chdir to root directory\n");
-				exit(1);
-			}
-		}
+		ibonl( ud, 0 );
+		return -1;
 	}
+	if(ThreadIbsta() & ERR)
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "local detected"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	SetRWLS(board, addressList);
+	if(ThreadIbsta() & ERR)
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "set remote with lockout"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	if(sync_message(options, "lockout detected"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	if(ibsre(board, 0) & ERR)
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "lockout cleared"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	if(sync_message(options, "lockout clear detected"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	EnableRemote(board, addressList);
+	if(ThreadIbsta() & ERR)
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "remote enabled"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	if(sync_message(options, "remote detected"))
+	{
+		ibonl( ud, 0 );
+		return -1;
+	}
+	ibonl( ud, 0 );
+	fprintf( stderr, "OK\n" );
+	return 0;
+}
+
+static int slave_remote_and_lockout_test(int board, const struct program_options *options)
+{
+	int i;
+	static const int timeout = 100;
+	int failed = 0;
+	
+	fprintf( stderr, "%s...", __FUNCTION__ );
+
+	if(sync_message(options, "set local mode"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if((ibwait(board, 0) & REM))
+	{
+		fprintf(stderr, "REM did not clear.  ibsta=0x%x\n", ThreadIbsta());
+		PRINT_FAILED();
+		++failed;
+	}
+	if(sync_message(options, "local detected"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "set remote with lockout"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if((ibwait(board, LOK | TIMO) & LOK) == 0)
+	{
+		fprintf(stderr, "failed to detect LOK status.  ibsta=0x%x\n", ThreadIbsta());
+		PRINT_FAILED();
+		++failed;
+	}
+	if(sync_message(options, "lockout detected"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "lockout cleared"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(ibwait(board, 0) & LOK)
+	{
+		PRINT_FAILED();
+		++failed;
+	}
+	if(sync_message(options, "lockout clear detected"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(sync_message(options, "remote enabled"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if((ibwait(board, REM | TIMO) & REM) == 0)
+	{
+		PRINT_FAILED();
+		++failed;
+	}
+	if(sync_message(options, "remote detected"))
+	{
+		PRINT_FAILED();
+		return -1;
+	}
+	if(failed == 0)
+	{
+		fprintf( stderr, "OK\n" );
+		return 0;
+	}else
+		return -1;
 }
 
 int parse_program_options(int argc, char *argv[], struct program_options *options)
 {
 	static struct option long_options[] =
 	{
-		{"daemonize", optional_argument, NULL, 'd'},
 		{"num_loops", required_argument, NULL, 'n'},
 		{"master", no_argument, NULL, 'm'},
 		{"minor", required_argument, NULL, 'M'},
@@ -683,51 +847,43 @@ int parse_program_options(int argc, char *argv[], struct program_options *option
 	int option_index = 0;
 
 	memset(options, 0, sizeof(*options));
-	options->daemonize_index = -1;
 	options->num_loops = 1;
 	options->pad = 1;
 	options->sad = -1;
 	options->minor = -1;
 	while(1)
 	{
-		c = getopt_long(argc, argv, "d::n:mSp:s:v", long_options, &option_index);
+		c = getopt_long(argc, argv, "n:mSp:s:v", long_options, &option_index);
 		if(c < 0) break;
 		switch(c)
 		{
-		case 'd':
-			if(optarg)
-				options->daemonize_index = strtol(optarg, NULL, 0);
-			else
-				options->daemonize_index = 0;
-			fprintf(stdout, "option: daemonize after %ith loop\n", options->daemonize_index);
-			break;
 		case 'n':
 			options->num_loops = strtol(optarg, NULL, 0);
-			fprintf(stdout, "option: loop %i times\n", options->num_loops);
+			fprintf(stderr, "option: loop %i times\n", options->num_loops);
 			break;
 		case 'm':
 			options->master = 1;
-			fprintf(stdout, "option: run as bus master\n");
+			fprintf(stderr, "option: run as bus master\n");
 			break;
 		case 'M':
 			options->minor = strtol(optarg, NULL, 0);
-			fprintf(stdout, "option: minor %i\n", options->minor);
+			fprintf(stderr, "option: minor %i\n", options->minor);
 			break;
 		case 'S':
 			options->master = 0;
-			fprintf(stdout, "option: run as slave\n");
+			fprintf(stderr, "option: run as slave\n");
 			break;
 		case 'p':
 			options->pad = strtol(optarg, NULL, 0);
-			fprintf(stdout, "option: pad %i\n", options->pad);
+			fprintf(stderr, "option: pad %i\n", options->pad);
 			break;
 		case 's':
 			options->sad = strtol(optarg, NULL, 0);
-			fprintf(stdout, "option: sad %i\n", options->sad);
+			fprintf(stderr, "option: sad %i\n", options->sad);
 			break;
 		case 'v':
 			options->verbosity = 1;
-			fprintf(stdout, "option: verbose\n");
+			fprintf(stderr, "option: verbose\n");
 			break;
 		default:
 			fprintf(stderr, "bad option?\n");
@@ -750,21 +906,44 @@ int main( int argc, char *argv[] )
 
 	for(i = 0; i < options.num_loops; i++)
 	{
-		if(i == options.daemonize_index)
-			daemonize();
-		retval = find_board(&board, &options);
-		if( retval < 0 ) return retval;
-		retval = read_write_test(board, &options);
-		if( retval < 0 ) return retval;
-		retval = async_read_write_test(board, &options);
-		if( retval < 0 ) return retval;
-		retval = serial_poll_test(board, &options);
-		if( retval < 0 ) return retval;
-		retval = parallel_poll_test(board, &options);
-		if( retval < 0 ) return retval;
-		retval = eos_test(board, &options);
-		if( retval < 0 ) return retval;
- }
+		if(options.master)
+		{
+			if(sync_message(&options, "found slave board"))
+				return -1;
+			retval = find_board(&board, &options);
+			if( retval < 0 ) return retval;
+			retval = master_read_write_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = master_async_read_write_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = master_serial_poll_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = master_parallel_poll_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = master_eos_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = master_remote_and_lockout_test(board, &options);
+			if( retval < 0 ) return retval;
+		}else
+		{
+			retval = find_board(&board, &options);
+			if( retval < 0 ) return retval;
+			if(sync_message(&options, "found slave board"))
+				return -1;
+			retval = slave_read_write_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = slave_async_read_write_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = slave_serial_poll_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = slave_parallel_poll_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = slave_eos_test(board, &options);
+			if( retval < 0 ) return retval;
+			retval = slave_remote_and_lockout_test(board, &options);
+			if( retval < 0 ) return retval;
+		}
+	}
 	return 0;
 }
 
